"""
Python module generated from Java source file org.bukkit.generator.structure.StructurePiece

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.generator.structure import *
from org.bukkit.util import BoundingBox
from typing import Any, Callable, Iterable, Tuple


class StructurePiece:
    """
    Represents an individual part of a GeneratedStructure.

    See
    - GeneratedStructure
    """

    def getBoundingBox(self) -> "BoundingBox":
        """
        Gets the bounding box of this structure piece.

        Returns
        - bounding box of this structure piece
        """
        ...



"""
Python module generated from Java source file java.io.Reader

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class Reader(Readable, Closeable):

    @staticmethod
    def nullReader() -> "Reader":
        """
        Returns a new `Reader` that reads no characters. The returned
        stream is initially open.  The stream is closed by calling the
        `close()` method.  Subsequent calls to `close()` have no
        effect.
        
         While the stream is open, the `read()`, `read(char[])`,
        `read(char[], int, int)`, `read(CharBuffer)`, `ready()`, `skip(long)`, and `transferTo()` methods all
        behave as if end of stream has been reached. After the stream has been
        closed, these methods all throw `IOException`.
        
         The `markSupported()` method returns `False`.  The
        `mark()` and `reset()` methods throw an `IOException`.
        
         The .lock object used to synchronize operations on the
        returned `Reader` is not specified.

        Returns
        - a `Reader` which reads no characters

        Since
        - 11
        """
        ...


    def read(self, target: "CharBuffer") -> int:
        """
        Attempts to read characters into the specified character buffer.
        The buffer is used as a repository of characters as-is: the only
        changes made are the results of a put operation. No flipping or
        rewinding of the buffer is performed.

        Arguments
        - target: the buffer to read characters into

        Returns
        - The number of characters added to the buffer, or
                -1 if this source of characters is at its end

        Raises
        - IOException: if an I/O error occurs
        - NullPointerException: if target is null
        - java.nio.ReadOnlyBufferException: if target is a read only buffer

        Since
        - 1.5
        """
        ...


    def read(self) -> int:
        """
        Reads a single character.  This method will block until a character is
        available, an I/O error occurs, or the end of the stream is reached.
        
         Subclasses that intend to support efficient single-character input
        should override this method.

        Returns
        - The character read, as an integer in the range 0 to 65535
                    (`0x00-0xffff`), or -1 if the end of the stream has
                    been reached

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def read(self, cbuf: list[str]) -> int:
        """
        Reads characters into an array.  This method will block until some input
        is available, an I/O error occurs, or the end of the stream is reached.
        
         If the length of `cbuf` is zero, then no characters are read
        and `0` is returned; otherwise, there is an attempt to read at
        least one character.  If no character is available because the stream is
        at its end, the value `-1` is returned; otherwise, at least one
        character is read and stored into `cbuf`.

        Arguments
        - cbuf: Destination buffer

        Returns
        - The number of characters read, or -1
                     if the end of the stream
                     has been reached

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def read(self, cbuf: list[str], off: int, len: int) -> int:
        """
        Reads characters into a portion of an array.  This method will block
        until some input is available, an I/O error occurs, or the end of the
        stream is reached.
        
         If `len` is zero, then no characters are read and `0` is
        returned; otherwise, there is an attempt to read at least one character.
        If no character is available because the stream is at its end, the value
        `-1` is returned; otherwise, at least one character is read and
        stored into `cbuf`.

        Arguments
        - cbuf: Destination buffer
        - off: Offset at which to start storing characters
        - len: Maximum number of characters to read

        Returns
        - The number of characters read, or -1 if the end of the
                    stream has been reached

        Raises
        - IndexOutOfBoundsException: If `off` is negative, or `len` is negative,
                    or `len` is greater than `cbuf.length - off`
        - IOException: If an I/O error occurs
        """
        ...


    def skip(self, n: int) -> int:
        """
        Skips characters.  This method will block until some characters are
        available, an I/O error occurs, or the end of the stream is reached.
        If the stream is already at its end before this method is invoked,
        then no characters are skipped and zero is returned.

        Arguments
        - n: The number of characters to skip

        Returns
        - The number of characters actually skipped

        Raises
        - IllegalArgumentException: If `n` is negative.
        - IOException: If an I/O error occurs
        """
        ...


    def ready(self) -> bool:
        """
        Tells whether this stream is ready to be read.

        Returns
        - True if the next read() is guaranteed not to block for input,
        False otherwise.  Note that returning False does not guarantee that the
        next read will block.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def markSupported(self) -> bool:
        """
        Tells whether this stream supports the mark() operation. The default
        implementation always returns False. Subclasses should override this
        method.

        Returns
        - True if and only if this stream supports the mark operation.
        """
        ...


    def mark(self, readAheadLimit: int) -> None:
        """
        Marks the present position in the stream.  Subsequent calls to reset()
        will attempt to reposition the stream to this point.  Not all
        character-input streams support the mark() operation.

        Arguments
        - readAheadLimit: Limit on the number of characters that may be
                                read while still preserving the mark.  After
                                reading this many characters, attempting to
                                reset the stream may fail.

        Raises
        - IOException: If the stream does not support mark(),
                                 or if some other I/O error occurs
        """
        ...


    def reset(self) -> None:
        """
        Resets the stream.  If the stream has been marked, then attempt to
        reposition it at the mark.  If the stream has not been marked, then
        attempt to reset it in some way appropriate to the particular stream,
        for example by repositioning it to its starting point.  Not all
        character-input streams support the reset() operation, and some support
        reset() without supporting mark().

        Raises
        - IOException: If the stream has not been marked,
                                 or if the mark has been invalidated,
                                 or if the stream does not support reset(),
                                 or if some other I/O error occurs
        """
        ...


    def close(self) -> None:
        """
        Closes the stream and releases any system resources associated with
        it.  Once the stream has been closed, further read(), ready(),
        mark(), reset(), or skip() invocations will throw an IOException.
        Closing a previously closed stream has no effect.

        Raises
        - IOException: If an I/O error occurs
        """
        ...


    def transferTo(self, out: "Writer") -> int:
        """
        Reads all characters from this reader and writes the characters to the
        given writer in the order that they are read. On return, this reader
        will be at end of the stream. This method does not close either reader
        or writer.
        
        This method may block indefinitely reading from the reader, or
        writing to the writer. The behavior for the case where the reader
        and/or writer is *asynchronously closed*, or the thread
        interrupted during the transfer, is highly reader and writer
        specific, and therefore not specified.
        
        If an I/O error occurs reading from the reader or writing to the
        writer, then it may do so after some characters have been read or
        written. Consequently the reader may not be at end of the stream and
        one, or both, streams may be in an inconsistent state. It is strongly
        recommended that both streams be promptly closed if an I/O error occurs.

        Arguments
        - out: the writer, non-null

        Returns
        - the number of characters transferred

        Raises
        - IOException: if an I/O error occurs when reading or writing
        - NullPointerException: if `out` is `null`

        Since
        - 10
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingBlockingDeque

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.util.concurrent import BlockingDeque
from java.util.concurrent import TimeUnit
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ForwardingBlockingDeque(ForwardingDeque, BlockingDeque):
    """
    A BlockingDeque which forwards all its method calls to another `BlockingDeque`.
    Subclasses should override one or more methods to modify the behavior of the backing deque as
    desired per the <a href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingBlockingDeque` forward **indiscriminately**
    to the methods of the delegate. For example, overriding .add alone **will not** change
    the behaviour of .offer which can lead to unexpected behaviour. In this case, you should
    override `offer` as well, either providing your own implementation, or delegating to the
    provided `standardOffer` method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingBlockingDeque`.
    
    The `standard` methods are not guaranteed to be thread-safe, even when all of the
    methods that they depend on are thread-safe.

    Author(s)
    - Emily Soldal

    Since
    - 14.0

    Deprecated
    - This class has moved to `com.google.common.util.concurrent`. Please use com.google.common.util.concurrent.ForwardingBlockingDeque instead.
    """

    def remainingCapacity(self) -> int:
        ...


    def putFirst(self, e: "E") -> None:
        ...


    def putLast(self, e: "E") -> None:
        ...


    def offerFirst(self, e: "E", timeout: int, unit: "TimeUnit") -> bool:
        ...


    def offerLast(self, e: "E", timeout: int, unit: "TimeUnit") -> bool:
        ...


    def takeFirst(self) -> "E":
        ...


    def takeLast(self) -> "E":
        ...


    def pollFirst(self, timeout: int, unit: "TimeUnit") -> "E":
        ...


    def pollLast(self, timeout: int, unit: "TimeUnit") -> "E":
        ...


    def put(self, e: "E") -> None:
        ...


    def offer(self, e: "E", timeout: int, unit: "TimeUnit") -> bool:
        ...


    def take(self) -> "E":
        ...


    def poll(self, timeout: int, unit: "TimeUnit") -> "E":
        ...


    def drainTo(self, c: Iterable["E"]) -> int:
        ...


    def drainTo(self, c: Iterable["E"], maxElements: int) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.entity.memory.MemoryKey

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import UUID
from org.bukkit import Keyed
from org.bukkit import Location
from org.bukkit import NamespacedKey
from org.bukkit.entity.memory import *
from org.bukkit.registry import RegistryAware
from typing import Any, Callable, Iterable, Tuple


class MemoryKey(Keyed, RegistryAware):
    """
    Represents a key used for accessing memory values of a
    org.bukkit.entity.LivingEntity.
    
    Type `<T>`: the class type of the memory value
    """

    HOME = MemoryKey<>(NamespacedKey.minecraft("home"), Location.class)
    POTENTIAL_JOB_SITE = MemoryKey<>(NamespacedKey.minecraft("potential_job_site"), Location.class)
    JOB_SITE = MemoryKey<>(NamespacedKey.minecraft("job_site"), Location.class)
    MEETING_POINT = MemoryKey<>(NamespacedKey.minecraft("meeting_point"), Location.class)
    GOLEM_DETECTED_RECENTLY = MemoryKey<>(NamespacedKey.minecraft("golem_detected_recently"), Boolean.class)
    LAST_SLEPT = MemoryKey<>(NamespacedKey.minecraft("last_slept"), Long.class)
    LAST_WOKEN = MemoryKey<>(NamespacedKey.minecraft("last_woken"), Long.class)
    LAST_WORKED_AT_POI = MemoryKey<>(NamespacedKey.minecraft("last_worked_at_poi"), Long.class)
    UNIVERSAL_ANGER = MemoryKey<>(NamespacedKey.minecraft("universal_anger"), Boolean.class)
    ANGRY_AT = MemoryKey<>(NamespacedKey.minecraft("angry_at"), UUID.class)
    ADMIRING_ITEM = MemoryKey<>(NamespacedKey.minecraft("admiring_item"), Boolean.class)
    ADMIRING_DISABLED = MemoryKey<>(NamespacedKey.minecraft("admiring_disabled"), Boolean.class)
    HUNTED_RECENTLY = MemoryKey<>(NamespacedKey.minecraft("hunted_recently"), Boolean.class)
    PLAY_DEAD_TICKS = MemoryKey<>(NamespacedKey.minecraft("play_dead_ticks"), Integer.class)
    TEMPTATION_COOLDOWN_TICKS = MemoryKey<>(NamespacedKey.minecraft("temptation_cooldown_ticks"), Integer.class)
    IS_TEMPTED = MemoryKey<>(NamespacedKey.minecraft("is_tempted"), Boolean.class)
    LONG_JUMP_COOLING_DOWN = MemoryKey<>(NamespacedKey.minecraft("long_jump_cooling_down"), Integer.class)
    HAS_HUNTING_COOLDOWN = MemoryKey<>(NamespacedKey.minecraft("has_hunting_cooldown"), Boolean.class)
    RAM_COOLDOWN_TICKS = MemoryKey<>(NamespacedKey.minecraft("ram_cooldown_ticks"), Integer.class)
    LIKED_PLAYER = MemoryKey<>(NamespacedKey.minecraft("liked_player"), UUID.class)
    LIKED_NOTEBLOCK_POSITION = MemoryKey<>(NamespacedKey.minecraft("liked_noteblock"), Location.class)
    LIKED_NOTEBLOCK_COOLDOWN_TICKS = MemoryKey<>(NamespacedKey.minecraft("liked_noteblock_cooldown_ticks"), Integer.class)
    ITEM_PICKUP_COOLDOWN_TICKS = MemoryKey<>(NamespacedKey.minecraft("item_pickup_cooldown_ticks"), Integer.class)
    SNIFFER_EXPLORED_POSITIONS = MemoryKey<>(NamespacedKey.minecraft("sniffer_explored_positions"), Location.class)


    def getKeyOrThrow(self) -> "NamespacedKey":
        ...


    def getKeyOrNull(self) -> "NamespacedKey":
        ...


    def isRegistered(self) -> bool:
        ...


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...


    def getMemoryClass(self) -> type["T"]:
        """
        Gets the class of values associated with this memory.

        Returns
        - the class of value objects
        """
        ...


    @staticmethod
    def getByKey(namespacedKey: "NamespacedKey") -> "MemoryKey":
        """
        Returns a MemoryKey by a NamespacedKey.

        Arguments
        - namespacedKey: the NamespacedKey referencing a
        MemoryKey

        Returns
        - the MemoryKey or null when no MemoryKey is
        available under that key
        """
        ...


    @staticmethod
    def values() -> set["MemoryKey"]:
        """
        Returns the set of all MemoryKeys.

        Returns
        - the memoryKeys
        """
        ...



"""
Python module generated from Java source file com.google.common.io.MultiInputStream

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from java.io import IOException
from java.io import InputStream
from java.util import Iterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class MultiInputStream(InputStream):
    """
    An InputStream that concatenates multiple substreams. At most one stream will be open at
    a time.

    Author(s)
    - Chris Nokleberg

    Since
    - 1.0
    """

    def __init__(self, it: Iterator["ByteSource"]):
        """
        Creates a new instance.

        Arguments
        - it: an iterator of I/O suppliers that will provide each substream
        """
        ...


    def close(self) -> None:
        ...


    def available(self) -> int:
        ...


    def markSupported(self) -> bool:
        ...


    def read(self) -> int:
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        ...


    def skip(self, n: int) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.ItemStack

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import ImmutableMap
from java.util import Locale
from org.bukkit import Bukkit
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit import Translatable
from org.bukkit import Utility
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.enchantments import Enchantment
from org.bukkit.inventory import *
from org.bukkit.inventory.meta import Damageable
from org.bukkit.inventory.meta import ItemMeta
from org.bukkit.material import MaterialData
from typing import Any, Callable, Iterable, Tuple


class ItemStack(Cloneable, ConfigurationSerializable, Translatable):
    """
    Represents a stack of items.
    
    **IMPORTANT: An *Item*Stack is only designed to contain *items*. Do not
    use this class to encapsulate Materials for which Material.isItem()
    returns False.**
    """

    def __init__(self, type: "Material"):
        """
        Defaults stack size to 1, with no extra data.
        
        **IMPORTANT: An *Item*Stack is only designed to contain
        *items*. Do not use this class to encapsulate Materials for which
        Material.isItem() returns False.**

        Arguments
        - type: item material
        """
        ...


    def __init__(self, type: "Material", amount: int):
        """
        An item stack with no extra data.
        
        **IMPORTANT: An *Item*Stack is only designed to contain
        *items*. Do not use this class to encapsulate Materials for which
        Material.isItem() returns False.**

        Arguments
        - type: item material
        - amount: stack size
        """
        ...


    def __init__(self, type: "Material", amount: int, damage: int):
        """
        An item stack with the specified damage / durability

        Arguments
        - type: item material
        - amount: stack size
        - damage: durability / damage

        Deprecated
        - see .setDurability(short)
        """
        ...


    def __init__(self, type: "Material", amount: int, damage: int, data: "Byte"):
        """
        Arguments
        - type: the type
        - amount: the amount in the stack
        - damage: the damage value of the item
        - data: the data value or null

        Deprecated
        - this method uses an ambiguous data byte object
        """
        ...


    def __init__(self, stack: "ItemStack"):
        """
        Creates a new item stack derived from the specified stack

        Arguments
        - stack: the stack to copy

        Raises
        - IllegalArgumentException: if the specified stack is null or
            returns an item meta not created by the item factory
        """
        ...


    def getType(self) -> "Material":
        """
        Gets the type of this item

        Returns
        - Type of the items in this stack
        """
        ...


    def setType(self, type: "Material") -> None:
        """
        Sets the type of this item
        
        Note that in doing so you will reset the MaterialData for this stack.
        
        **IMPORTANT: An *Item*Stack is only designed to contain
        *items*. Do not use this class to encapsulate Materials for which
        Material.isItem() returns False.**

        Arguments
        - type: New type to set the items in this stack to
        """
        ...


    def getAmount(self) -> int:
        """
        Gets the amount of items in this stack

        Returns
        - Amount of items in this stack
        """
        ...


    def setAmount(self, amount: int) -> None:
        """
        Sets the amount of items in this stack

        Arguments
        - amount: New amount of items in this stack
        """
        ...


    def getData(self) -> "MaterialData":
        """
        Gets the MaterialData for this stack of items

        Returns
        - MaterialData for this item
        """
        ...


    def setData(self, data: "MaterialData") -> None:
        """
        Sets the MaterialData for this stack of items

        Arguments
        - data: New MaterialData for this item
        """
        ...


    def setDurability(self, durability: int) -> None:
        """
        Sets the durability of this item

        Arguments
        - durability: Durability of this item

        Deprecated
        - durability is now part of ItemMeta. To avoid confusion and
        misuse, .getItemMeta(), .setItemMeta(ItemMeta) and
        Damageable.setDamage(int) should be used instead. This is because
        any call to this method will be overwritten by subsequent setting of
        ItemMeta which was created before this call.
        """
        ...


    def getDurability(self) -> int:
        """
        Gets the durability of this item

        Returns
        - Durability of this item

        Deprecated
        - see .setDurability(short)
        """
        ...


    def getMaxStackSize(self) -> int:
        """
        Get the maximum stack size for this item. If this item has a max stack
        size component (ItemMeta.hasMaxStackSize()), the value of that
        component will be returned. Otherwise, this item's Material's Material.getMaxStackSize() default maximum stack size will be returned
        instead.

        Returns
        - The maximum you can stack this item to.
        """
        ...


    def toString(self) -> str:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def isSimilar(self, stack: "ItemStack") -> bool:
        """
        This method is the same as equals, but does not consider stack size
        (amount).

        Arguments
        - stack: the item stack to compare to

        Returns
        - True if the two stacks are equal, ignoring the amount
        """
        ...


    def clone(self) -> "ItemStack":
        ...


    def hashCode(self) -> int:
        ...


    def containsEnchantment(self, ench: "Enchantment") -> bool:
        """
        Checks if this ItemStack contains the given Enchantment

        Arguments
        - ench: Enchantment to test

        Returns
        - True if this has the given enchantment
        """
        ...


    def getEnchantmentLevel(self, ench: "Enchantment") -> int:
        """
        Gets the level of the specified enchantment on this item stack

        Arguments
        - ench: Enchantment to check

        Returns
        - Level of the enchantment, or 0
        """
        ...


    def getEnchantments(self) -> dict["Enchantment", "Integer"]:
        """
        Gets a map containing all enchantments and their levels on this item.

        Returns
        - Map of enchantments.
        """
        ...


    def addEnchantments(self, enchantments: dict["Enchantment", "Integer"]) -> None:
        """
        Adds the specified enchantments to this item stack.
        
        This method is the same as calling .addEnchantment(org.bukkit.enchantments.Enchantment, int) for each
        element of the map.

        Arguments
        - enchantments: Enchantments to add

        Raises
        - IllegalArgumentException: if the specified enchantments is null
        - IllegalArgumentException: if any specific enchantment or level
            is null. **Warning**: Some enchantments may be added before this
            exception is thrown.
        """
        ...


    def addEnchantment(self, ench: "Enchantment", level: int) -> None:
        """
        Adds the specified Enchantment to this item stack.
        
        If this item stack already contained the given enchantment (at any
        level), it will be replaced.

        Arguments
        - ench: Enchantment to add
        - level: Level of the enchantment

        Raises
        - IllegalArgumentException: if enchantment null, or enchantment is
            not applicable
        """
        ...


    def addUnsafeEnchantments(self, enchantments: dict["Enchantment", "Integer"]) -> None:
        """
        Adds the specified enchantments to this item stack in an unsafe manner.
        
        This method is the same as calling .addUnsafeEnchantment(org.bukkit.enchantments.Enchantment, int) for
        each element of the map.

        Arguments
        - enchantments: Enchantments to add
        """
        ...


    def addUnsafeEnchantment(self, ench: "Enchantment", level: int) -> None:
        """
        Adds the specified Enchantment to this item stack.
        
        If this item stack already contained the given enchantment (at any
        level), it will be replaced.
        
        This method is unsafe and will ignore level restrictions or item type.
        Use at your own discretion.

        Arguments
        - ench: Enchantment to add
        - level: Level of the enchantment
        """
        ...


    def removeEnchantment(self, ench: "Enchantment") -> int:
        """
        Removes the specified Enchantment if it exists on this
        ItemStack

        Arguments
        - ench: Enchantment to remove

        Returns
        - Previous level, or 0
        """
        ...


    def removeEnchantments(self) -> None:
        """
        Removes all enchantments on this ItemStack.
        """
        ...


    def serialize(self) -> dict[str, "Object"]:
        ...


    @staticmethod
    def deserialize(args: dict[str, "Object"]) -> "ItemStack":
        """
        Required method for configuration serialization

        Arguments
        - args: map to deserialize

        Returns
        - deserialized item stack

        See
        - ConfigurationSerializable
        """
        ...


    def getItemMeta(self) -> "ItemMeta":
        """
        Get a copy of this ItemStack's ItemMeta.

        Returns
        - a copy of the current ItemStack's ItemData
        """
        ...


    def hasItemMeta(self) -> bool:
        """
        Checks to see if any meta data has been defined.

        Returns
        - Returns True if some meta data has been set for this item
        """
        ...


    def setItemMeta(self, itemMeta: "ItemMeta") -> bool:
        """
        Set the ItemMeta of this ItemStack.

        Arguments
        - itemMeta: new ItemMeta, or null to indicate meta data be cleared.

        Returns
        - True if successfully applied ItemMeta, see ItemFactory.isApplicable(ItemMeta, ItemStack)

        Raises
        - IllegalArgumentException: if the item meta was not created by
            the ItemFactory
        """
        ...


    def getTranslationKey(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.collect.CollectSpliterators

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.j2objc.annotations import Weak
from java.util import Comparator
from java.util import Spliterator
from java.util.function import Consumer
from java.util.function import DoubleConsumer
from java.util.function import Function
from java.util.function import IntConsumer
from java.util.function import IntFunction
from java.util.function import LongConsumer
from java.util.function import Predicate
from java.util.stream import IntStream
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class CollectSpliterators:
    """
    Spliterator utilities for `common.collect` internals.
    """





"""
Python module generated from Java source file com.google.common.collect.RegularImmutableMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.common.collect.Multisets import ImmutableEntry
from com.google.common.primitives import Ints
from com.google.errorprone.annotations.concurrent import LazyInit
from java.util import Arrays
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class RegularImmutableMultiset(ImmutableMultiset):
    """
    Implementation of ImmutableMultiset with zero or more elements.

    Author(s)
    - Louis Wasserman
    """

    def count(self, element: "Object") -> int:
        ...


    def size(self) -> int:
        ...


    def elementSet(self) -> "ImmutableSet"["E"]:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.ExpBottleEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.entity import Entity
from org.bukkit.entity import ThrownExpBottle
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class ExpBottleEvent(ProjectileHitEvent):
    """
    Called when a ThrownExpBottle hits and releases experience.
    """

    def __init__(self, bottle: "ThrownExpBottle", exp: int):
        ...


    def __init__(self, bottle: "ThrownExpBottle", hitEntity: "Entity", hitBlock: "Block", hitFace: "BlockFace", exp: int):
        ...


    def getEntity(self) -> "ThrownExpBottle":
        ...


    def getShowEffect(self) -> bool:
        """
        This method indicates if the particle effect should be shown.

        Returns
        - True if the effect will be shown, False otherwise
        """
        ...


    def setShowEffect(self, showEffect: bool) -> None:
        """
        This method sets if the particle effect will be shown.
        
        This does not change the experience created.

        Arguments
        - showEffect: True indicates the effect will be shown, False
            indicates no effect will be shown
        """
        ...


    def getExperience(self) -> int:
        """
        This method retrieves the amount of experience to be created.
        
        The number indicates a total amount to be divided into orbs.

        Returns
        - the total amount of experience to be created
        """
        ...


    def setExperience(self, exp: int) -> None:
        """
        This method sets the amount of experience to be created.
        
        The number indicates a total amount to be divided into orbs.

        Arguments
        - exp: the total amount of experience to be created
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.gson.InstanceCreator

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from java.lang.reflect import Type
from typing import Any, Callable, Iterable, Tuple


class InstanceCreator:
    """
    This interface is implemented to create instances of a class that does not define a no-args
    constructor. If you can modify the class, you should instead add a private, or public no-args
    constructor. However, that is not possible for library classes, such as JDK classes, or a
    third-party library that you do not have source-code of. In such cases, you should define an
    instance creator for the class. Implementations of this interface should be registered with
    GsonBuilder.registerTypeAdapter(Type, Object) method before Gson will be able to use
    them.
    
    Let us look at an example where defining an InstanceCreator might be useful. The `Id`
    class defined below does not have a default no-args constructor.
    
    ```
    public class Id&lt;T&gt; {
      private final Class&lt;T&gt; clazz;
      private final long value;
      public Id(Class&lt;T&gt; clazz, long value) {
        this.clazz = clazz;
        this.value = value;
      }
    }
    ```
    
    If Gson encounters an object of type `Id` during deserialization, it will throw an
    exception. The easiest way to solve this problem will be to add a (public or private) no-args
    constructor as follows:
    
    ```
    private Id() {
      this(Object.class, 0L);
    }
    ```
    
    However, let us assume that the developer does not have access to the source-code of the
    `Id` class, or does not want to define a no-args constructor for it. The developer can
    solve this problem by defining an `InstanceCreator` for `Id`:
    
    ```
    class IdInstanceCreator implements InstanceCreator&lt;Id&gt; {
      public Id createInstance(Type type) {
        return new Id(Object.class, 0L);
      }
    }
    ```
    
    Note that it does not matter what the fields of the created instance contain since Gson will
    overwrite them with the deserialized values specified in JSON. You should also ensure that a
    *new* object is returned, not a common object since its fields will be overwritten. The
    developer will need to register `IdInstanceCreator` with Gson as follows:
    
    ```
    Gson gson = new GsonBuilder().registerTypeAdapter(Id.class, new IdInstanceCreator()).create();
    ```
    
    Type `<T>`: the type of object that will be created by this implementation.

    Author(s)
    - Joel Leitch

    See
    - GsonBuilder.registerTypeAdapter(Type, Object)
    """

    def createInstance(self, type: "Type") -> "T":
        """
        Gson invokes this call-back method during deserialization to create an instance of the
        specified type. The fields of the returned instance are overwritten with the data present in
        the JSON. Since the prior contents of the object are destroyed and overwritten, do not return
        an instance that is useful elsewhere. In particular, do not return a common instance, always
        use `new` to create a new instance.

        Arguments
        - type: the parameterized T represented as a Type.

        Returns
        - a default object instance of type T.
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ListeningExecutorService

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import DoNotMock
from java.time import Duration
from java.util.concurrent import Callable
from java.util.concurrent import ExecutionException
from java.util.concurrent import ExecutorService
from java.util.concurrent import Future
from java.util.concurrent import RejectedExecutionException
from java.util.concurrent import TimeUnit
from java.util.concurrent import TimeoutException
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ListeningExecutorService(ExecutorService):
    """
    An ExecutorService that returns ListenableFuture instances. To create an instance
    from an existing ExecutorService, call MoreExecutors.listeningDecorator(ExecutorService).

    Author(s)
    - Chris Povirk

    Since
    - 10.0
    """

    def submit(self, task: "Callable"["T"]) -> "ListenableFuture"["T"]:
        """
        Returns
        - a `ListenableFuture` representing pending completion of the task

        Raises
        - RejectedExecutionException: 
        """
        ...


    def submit(self, task: "Runnable") -> "ListenableFuture"[Any]:
        """
        Returns
        - a `ListenableFuture` representing pending completion of the task

        Raises
        - RejectedExecutionException: 
        """
        ...


    def submit(self, task: "Runnable", result: "T") -> "ListenableFuture"["T"]:
        """
        Returns
        - a `ListenableFuture` representing pending completion of the task

        Raises
        - RejectedExecutionException: 
        """
        ...


    def invokeAll(self, tasks: Iterable["Callable"["T"]]) -> list["Future"["T"]]:
        """
        
        
        All elements in the returned list must be ListenableFuture instances. The easiest
        way to obtain a `List<ListenableFuture<T>>` from this method is an unchecked (but safe)
        cast:
        
        ```
          `@SuppressWarnings("unchecked") // guaranteed by invokeAll contract`
          `List<ListenableFuture<T>> futures = (List) executor.invokeAll(tasks);`
        ```

        Returns
        - A list of `ListenableFuture` instances representing the tasks, in the same
            sequential order as produced by the iterator for the given task list, each of which has
            completed.

        Raises
        - RejectedExecutionException: 
        - NullPointerException: if any task is null
        """
        ...


    def invokeAll(self, tasks: Iterable["Callable"["T"]], timeout: int, unit: "TimeUnit") -> list["Future"["T"]]:
        """
        
        
        All elements in the returned list must be ListenableFuture instances. The easiest
        way to obtain a `List<ListenableFuture<T>>` from this method is an unchecked (but safe)
        cast:
        
        ```
          `@SuppressWarnings("unchecked") // guaranteed by invokeAll contract`
          `List<ListenableFuture<T>> futures = (List) executor.invokeAll(tasks, timeout, unit);`
        ```

        Returns
        - a list of `ListenableFuture` instances representing the tasks, in the same
            sequential order as produced by the iterator for the given task list. If the operation did
            not time out, each task will have completed. If it did time out, some of these tasks will
            not have completed.

        Raises
        - RejectedExecutionException: 
        - NullPointerException: if any task is null
        """
        ...


    def invokeAll(self, tasks: Iterable["Callable"["T"]], timeout: "Duration") -> list["Future"["T"]]:
        """
        Duration-based overload of .invokeAll(Collection, long, TimeUnit).

        Since
        - 32.1.0
        """
        ...


    def invokeAny(self, tasks: Iterable["Callable"["T"]], timeout: "Duration") -> "T":
        """
        Duration-based overload of .invokeAny(Collection, long, TimeUnit).

        Since
        - 32.1.0
        """
        ...


    def awaitTermination(self, timeout: "Duration") -> bool:
        """
        Duration-based overload of .awaitTermination(long, TimeUnit).

        Since
        - 32.1.0
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.StandardMutableGraph

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.graph import *
from com.google.common.graph.GraphConstants import Presence
from typing import Any, Callable, Iterable, Tuple


class StandardMutableGraph(ForwardingGraph, MutableGraph):
    """
    Standard implementation of MutableGraph that supports both directed and undirected
    graphs. Instances of this class should be constructed with GraphBuilder.
    
    Time complexities for mutation methods are all O(1) except for `removeNode(N node)`,
    which is in O(d_node) where d_node is the degree of `node`.
    
    Type `<N>`: Node parameter type

    Author(s)
    - James Sexton
    """

    def addNode(self, node: "N") -> bool:
        ...


    def putEdge(self, nodeU: "N", nodeV: "N") -> bool:
        ...


    def putEdge(self, endpoints: "EndpointPair"["N"]) -> bool:
        ...


    def removeNode(self, node: "N") -> bool:
        ...


    def removeEdge(self, nodeU: "N", nodeV: "N") -> bool:
        ...


    def removeEdge(self, endpoints: "EndpointPair"["N"]) -> bool:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.serializer.AnchorGenerator

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.serializer import *
from typing import Any, Callable, Iterable, Tuple


class AnchorGenerator:
    """
    Support different anchors
    """

    def nextAnchor(self, node: "Node") -> str:
        """
        Create a custom anchor to the provided Node

        Arguments
        - node: - the data to anchor

        Returns
        - value to be used in the YAML document
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.ItemMergeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Item
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class ItemMergeEvent(EntityEvent, Cancellable):

    def __init__(self, item: "Item", target: "Item"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getEntity(self) -> "Item":
        ...


    def getTarget(self) -> "Item":
        """
        Gets the Item entity the main Item is being merged into.

        Returns
        - The Item being merged with
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.parser.Parser

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.events import Event
from org.yaml.snakeyaml.parser import *
from typing import Any, Callable, Iterable, Tuple


class Parser:
    """
    This interface represents an input stream of Event Events.
    
    The parser and the scanner form together the 'Parse' step in the loading process (see chapter 3.1
    of the <a href="http://yaml.org/spec/1.1/">YAML Specification</a>).

    See
    - org.yaml.snakeyaml.events.Event
    """

    def checkEvent(self, choice: "Event.ID") -> bool:
        """
        Check if the next event is one of the given type.

        Arguments
        - choice: Event ID.

        Returns
        - `True` if the next event can be assigned to a variable of the given type.
                Returns `False` if no more events are available.

        Raises
        - ParserException: Thrown in case of malformed input.
        """
        ...


    def peekEvent(self) -> "Event":
        """
        Return the next event, but do not delete it from the stream.

        Returns
        - The event that will be returned on the next call to .getEvent

        Raises
        - ParserException: Thrown in case of malformed input.
        """
        ...


    def getEvent(self) -> "Event":
        """
        Returns the next event.
        
        The event will be removed from the stream.

        Returns
        - the next parsed event

        Raises
        - ParserException: Thrown in case of malformed input.
        """
        ...



"""
Python module generated from Java source file org.bukkit.configuration.serialization.ConfigurationSerializable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.configuration.serialization import *
from typing import Any, Callable, Iterable, Tuple


class ConfigurationSerializable:
    """
    Represents an object that may be serialized.
    
    These objects MUST implement one of the following, in addition to the
    methods as defined by this interface:
    
    - A static method "deserialize" that accepts a single Map&lt;
    String, Object&gt; and returns the class.
    - A static method "valueOf" that accepts a single Map&lt;String, Object&gt; and returns the class.
    - A constructor that accepts a single Map&lt;String,
    Object&gt;.
    
    In addition to implementing this interface, you must register the class
    with ConfigurationSerialization.registerClass(Class).

    See
    - SerializableAs
    """

    def serialize(self) -> dict[str, "Object"]:
        """
        Creates a Map representation of this class.
        
        This class must provide a method to restore this class, as defined in
        the ConfigurationSerializable interface javadocs.

        Returns
        - Map containing the current state of this class
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.ConcurrentMap

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Objects
from java.util.concurrent import *
from java.util.function import BiConsumer
from java.util.function import BiFunction
from java.util.function import Function
from typing import Any, Callable, Iterable, Tuple


class ConcurrentMap(Map):
    """
    A Map providing thread safety and atomicity guarantees.
    
    To maintain the specified guarantees, default implementations of
    methods including .putIfAbsent inherited from Map
    must be overridden by implementations of this interface. Similarly,
    implementations of the collections returned by methods .keySet, .values, and .entrySet must override
    methods such as `removeIf` when necessary to
    preserve atomicity guarantees.
    
    Memory consistency effects: As with other concurrent
    collections, actions in a thread prior to placing an object into a
    `ConcurrentMap` as a key or value
    <a href="package-summary.html#MemoryVisibility">*happen-before*</a>
    actions subsequent to the access or removal of that object from
    the `ConcurrentMap` in another thread.
    
    This interface is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<K>`: the type of keys maintained by this map
    
    Type `<V>`: the type of mapped values

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def getOrDefault(self, key: "Object", defaultValue: "V") -> "V":
        """
        Raises
        - ClassCastException: 
        - NullPointerException: 

        Since
        - 1.8

        Unknown Tags
        - This implementation assumes that the ConcurrentMap cannot
        contain null values and `get()` returning null unambiguously means
        the key is absent. Implementations which support null values
        <strong>must</strong> override this default implementation.
        """
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        """
        Raises
        - NullPointerException: 

        Since
        - 1.8

        Unknown Tags
        - The default implementation is equivalent to, for this
        `map`:
        ``` `for (Map.Entry<K,V> entry : map.entrySet()) {
          action.accept(entry.getKey(), entry.getValue());`}```
        - The default implementation assumes that
        `IllegalStateException` thrown by `getKey()` or
        `getValue()` indicates that the entry has been removed and cannot
        be processed. Operation continues for subsequent entries.
        """
        ...


    def putIfAbsent(self, key: "K", value: "V") -> "V":
        """
        If the specified key is not already associated
        with a value, associates it with the given value.
        This is equivalent to, for this `map`:
        ``` `if (!map.containsKey(key))
          return map.put(key, value);
        else
          return map.get(key);````
        
        except that the action is performed atomically.

        Arguments
        - key: key with which the specified value is to be associated
        - value: value to be associated with the specified key

        Returns
        - the previous value associated with the specified key, or
                `null` if there was no mapping for the key.
                (A `null` return can also indicate that the map
                previously associated `null` with the key,
                if the implementation supports null values.)

        Raises
        - UnsupportedOperationException: if the `put` operation
                is not supported by this map
        - ClassCastException: if the class of the specified key or value
                prevents it from being stored in this map
        - NullPointerException: if the specified key or value is null,
                and this map does not permit null keys or values
        - IllegalArgumentException: if some property of the specified key
                or value prevents it from being stored in this map

        Unknown Tags
        - This implementation intentionally re-abstracts the
        inappropriate default provided in `Map`.
        """
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        """
        Removes the entry for a key only if currently mapped to a given value.
        This is equivalent to, for this `map`:
        ``` `if (map.containsKey(key)
            && Objects.equals(map.get(key), value)) {
          map.remove(key);
          return True;` else {
          return False;
        }}```
        
        except that the action is performed atomically.

        Arguments
        - key: key with which the specified value is associated
        - value: value expected to be associated with the specified key

        Returns
        - `True` if the value was removed

        Raises
        - UnsupportedOperationException: if the `remove` operation
                is not supported by this map
        - ClassCastException: if the key or value is of an inappropriate
                type for this map
        (<a href="/java.base/java/util/Collection.html#optional-restrictions">optional</a>)
        - NullPointerException: if the specified key or value is null,
                and this map does not permit null keys or values
        (<a href="/java.base/java/util/Collection.html#optional-restrictions">optional</a>)

        Unknown Tags
        - This implementation intentionally re-abstracts the
        inappropriate default provided in `Map`.
        """
        ...


    def replace(self, key: "K", oldValue: "V", newValue: "V") -> bool:
        """
        Replaces the entry for a key only if currently mapped to a given value.
        This is equivalent to, for this `map`:
        ``` `if (map.containsKey(key)
            && Objects.equals(map.get(key), oldValue)) {
          map.put(key, newValue);
          return True;` else {
          return False;
        }}```
        
        except that the action is performed atomically.

        Arguments
        - key: key with which the specified value is associated
        - oldValue: value expected to be associated with the specified key
        - newValue: value to be associated with the specified key

        Returns
        - `True` if the value was replaced

        Raises
        - UnsupportedOperationException: if the `put` operation
                is not supported by this map
        - ClassCastException: if the class of a specified key or value
                prevents it from being stored in this map
        - NullPointerException: if a specified key or value is null,
                and this map does not permit null keys or values
        - IllegalArgumentException: if some property of a specified key
                or value prevents it from being stored in this map

        Unknown Tags
        - This implementation intentionally re-abstracts the
        inappropriate default provided in `Map`.
        """
        ...


    def replace(self, key: "K", value: "V") -> "V":
        """
        Replaces the entry for a key only if currently mapped to some value.
        This is equivalent to, for this `map`:
        ``` `if (map.containsKey(key))
          return map.put(key, value);
        else
          return null;````
        
        except that the action is performed atomically.

        Arguments
        - key: key with which the specified value is associated
        - value: value to be associated with the specified key

        Returns
        - the previous value associated with the specified key, or
                `null` if there was no mapping for the key.
                (A `null` return can also indicate that the map
                previously associated `null` with the key,
                if the implementation supports null values.)

        Raises
        - UnsupportedOperationException: if the `put` operation
                is not supported by this map
        - ClassCastException: if the class of the specified key or value
                prevents it from being stored in this map
        - NullPointerException: if the specified key or value is null,
                and this map does not permit null keys or values
        - IllegalArgumentException: if some property of the specified key
                or value prevents it from being stored in this map

        Unknown Tags
        - This implementation intentionally re-abstracts the
        inappropriate default provided in `Map`.
        """
        ...


    def replaceAll(self, function: "BiFunction"["K", "V", "V"]) -> None:
        """
        Raises
        - UnsupportedOperationException: 
        - NullPointerException: 
        - ClassCastException: 
        - IllegalArgumentException: 

        Since
        - 1.8

        Unknown Tags
        - The default implementation is equivalent to, for this `map`:
        ``` `for (Map.Entry<K,V> entry : map.entrySet()) {
          K k;
          V v;
          do {
            k = entry.getKey();
            v = entry.getValue();` while (!map.replace(k, v, function.apply(k, v)));
        }}```
        
        The default implementation may retry these steps when multiple
        threads attempt updates including potentially calling the function
        repeatedly for a given key.
        
        This implementation assumes that the ConcurrentMap cannot contain null
        values and `get()` returning null unambiguously means the key is
        absent. Implementations which support null values <strong>must</strong>
        override this default implementation.
        """
        ...


    def computeIfAbsent(self, key: "K", mappingFunction: "Function"["K", "V"]) -> "V":
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 

        Since
        - 1.8

        Unknown Tags
        - The default implementation is equivalent to the following steps for this
        `map`:
        
        ``` `V oldValue, newValue;
        return ((oldValue = map.get(key)) == null
                && (newValue = mappingFunction.apply(key)) != null
                && (oldValue = map.putIfAbsent(key, newValue)) == null)
          ? newValue
          : oldValue;````
        
        This implementation assumes that the ConcurrentMap cannot contain null
        values and `get()` returning null unambiguously means the key is
        absent. Implementations which support null values <strong>must</strong>
        override this default implementation.
        """
        ...


    def computeIfPresent(self, key: "K", remappingFunction: "BiFunction"["K", "V", "V"]) -> "V":
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 

        Since
        - 1.8

        Unknown Tags
        - The default implementation is equivalent to performing the following
        steps for this `map`:
        
        ``` `for (V oldValue; (oldValue = map.get(key)) != null; ) {
          V newValue = remappingFunction.apply(key, oldValue);
          if ((newValue == null)
              ? map.remove(key, oldValue)
              : map.replace(key, oldValue, newValue))
            return newValue;`
        return null;}```
        When multiple threads attempt updates, map operations and the
        remapping function may be called multiple times.
        
        This implementation assumes that the ConcurrentMap cannot contain null
        values and `get()` returning null unambiguously means the key is
        absent. Implementations which support null values <strong>must</strong>
        override this default implementation.
        """
        ...


    def compute(self, key: "K", remappingFunction: "BiFunction"["K", "V", "V"]) -> "V":
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 

        Since
        - 1.8

        Unknown Tags
        - The default implementation is equivalent to performing the following
        steps for this `map`:
        
        ``` `for (;;) {
          V oldValue = map.get(key);
          V newValue = remappingFunction.apply(key, oldValue);
          if (newValue != null) {
            if ((oldValue != null)
              ? map.replace(key, oldValue, newValue)
              : map.putIfAbsent(key, newValue) == null)
              return newValue;` else if (oldValue == null || map.remove(key, oldValue)) {
            return null;
          }
        }}```
        When multiple threads attempt updates, map operations and the
        remapping function may be called multiple times.
        
        This implementation assumes that the ConcurrentMap cannot contain null
        values and `get()` returning null unambiguously means the key is
        absent. Implementations which support null values <strong>must</strong>
        override this default implementation.
        """
        ...


    def merge(self, key: "K", value: "V", remappingFunction: "BiFunction"["V", "V", "V"]) -> "V":
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 

        Since
        - 1.8

        Unknown Tags
        - The default implementation is equivalent to performing the following
        steps for this `map`:
        
        ``` `for (;;) {
          V oldValue = map.get(key);
          if (oldValue != null) {
            V newValue = remappingFunction.apply(oldValue, value);
            if (newValue != null) {
              if (map.replace(key, oldValue, newValue))
                return newValue;` else if (map.remove(key, oldValue)) {
              return null;
            }
          } else if (map.putIfAbsent(key, value) == null) {
            return value;
          }
        }}```
        When multiple threads attempt updates, map operations and the
        remapping function may be called multiple times.
        
        This implementation assumes that the ConcurrentMap cannot contain null
        values and `get()` returning null unambiguously means the key is
        absent. Implementations which support null values <strong>must</strong>
        override this default implementation.
        """
        ...



"""
Python module generated from Java source file org.joml.Vector4i

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import Externalizable
from java.io import IOException
from java.io import ObjectInput
from java.io import ObjectOutput
from java.text import DecimalFormat
from java.text import NumberFormat
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class Vector4i(Externalizable, Cloneable, Vector4ic):
    """
    Contains the definition of a Vector comprising 4 ints and associated
    transformations.

    Author(s)
    - Hans Uhlig
    """

    def __init__(self):
        """
        Create a new Vector4i of `(0, 0, 0, 1)`.
        """
        ...


    def __init__(self, v: "Vector4ic"):
        """
        Create a new Vector4i with the same values as `v`.

        Arguments
        - v: the Vector4ic to copy the values from
        """
        ...


    def __init__(self, v: "Vector3ic", w: int):
        """
        Create a new Vector4i with the first three components from the
        given `v` and the given `w`.

        Arguments
        - v: the Vector3ic
        - w: the w component
        """
        ...


    def __init__(self, v: "Vector2ic", z: int, w: int):
        """
        Create a new Vector4i with the first two components from the
        given `v` and the given `z`, and `w`.

        Arguments
        - v: the Vector2ic
        - z: the z component
        - w: the w component
        """
        ...


    def __init__(self, v: "Vector3fc", w: float, mode: int):
        """
        Create a new Vector4i with the first three components from the
        given `v` and the given `w` and round using the given RoundingMode.

        Arguments
        - v: the Vector3fc to copy the values from
        - w: the w component
        - mode: the RoundingMode to use
        """
        ...


    def __init__(self, v: "Vector4fc", mode: int):
        """
        Create a new Vector4i and initialize its components to the rounded value of
        the given vector.

        Arguments
        - v: the Vector4fc to round and copy the values from
        - mode: the RoundingMode to use
        """
        ...


    def __init__(self, v: "Vector4dc", mode: int):
        """
        Create a new Vector4i and initialize its components to the rounded value of
        the given vector.

        Arguments
        - v: the Vector4dc to round and copy the values from
        - mode: the RoundingMode to use
        """
        ...


    def __init__(self, s: int):
        """
        Create a new Vector4i and initialize all four components with the
        given value.

        Arguments
        - s: scalar value of all four components
        """
        ...


    def __init__(self, x: int, y: int, z: int, w: int):
        """
        Create a new Vector4i with the given component values.

        Arguments
        - x: the x component
        - y: the y component
        - z: the z component
        - w: the w component
        """
        ...


    def __init__(self, xyzw: list[int]):
        """
        Create a new Vector4i and initialize its four components from the first
        four elements of the given array.

        Arguments
        - xyzw: the array containing at least four elements
        """
        ...


    def __init__(self, buffer: "ByteBuffer"):
        """
        Create a new Vector4i and read this vector from the supplied
        ByteBuffer at the current buffer
        ByteBuffer.position() position.
        
        This method will not increment the position of the given ByteBuffer.
        
        In order to specify the offset into the ByteBuffer at which the vector is
        read, use .Vector4i(int, ByteBuffer), taking the absolute
        position as parameter.

        Arguments
        - buffer: values will be read in `x, y, z, w` order

        See
        - .Vector4i(int, ByteBuffer)
        """
        ...


    def __init__(self, index: int, buffer: "ByteBuffer"):
        """
        Create a new Vector4i and read this vector from the supplied
        ByteBuffer starting at the specified absolute buffer
        position/index.
        
        This method will not increment the position of the given ByteBuffer.

        Arguments
        - index: the absolute position into the ByteBuffer
        - buffer: values will be read in `x, y, z, w` order
        """
        ...


    def __init__(self, buffer: "IntBuffer"):
        """
        Create a new Vector4i and read this vector from the supplied
        IntBuffer at the current buffer
        IntBuffer.position() position.
        
        This method will not increment the position of the given IntBuffer.
        
        In order to specify the offset into the IntBuffer at which the vector is
        read, use .Vector4i(int, IntBuffer), taking the absolute position
        as parameter.

        Arguments
        - buffer: values will be read in `x, y, z, w` order

        See
        - .Vector4i(int, IntBuffer)
        """
        ...


    def __init__(self, index: int, buffer: "IntBuffer"):
        """
        Create a new Vector4i and read this vector from the supplied
        IntBuffer starting at the specified absolute buffer
        position/index.
        
        This method will not increment the position of the given IntBuffer.

        Arguments
        - index: the absolute position into the IntBuffer
        - buffer: values will be read in `x, y, z, w` order
        """
        ...


    def x(self) -> int:
        ...


    def y(self) -> int:
        ...


    def z(self) -> int:
        ...


    def w(self) -> int:
        ...


    def xyz(self, dest: "Vector3f") -> "Vector3f":
        """
        Copy the `(x, y, z)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def xyz(self, dest: "Vector3d") -> "Vector3d":
        """
        Copy the `(x, y, z)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def xyz(self, dest: "Vector3i") -> "Vector3i":
        """
        Copy the `(x, y, z)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def xyz(self, dest: "Vector3L") -> "Vector3L":
        """
        Copy the `(x, y, z)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def xy(self, dest: "Vector2f") -> "Vector2f":
        """
        Copy the `(x, y)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def xy(self, dest: "Vector2d") -> "Vector2d":
        """
        Copy the `(x, y)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def xy(self, dest: "Vector2i") -> "Vector2i":
        """
        Copy the `(x, y)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def xy(self, dest: "Vector2L") -> "Vector2L":
        """
        Copy the `(x, y)` components of `this` into the supplied `dest` vector
        and return it.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def set(self, v: "Vector4ic") -> "Vector4i":
        """
        Set this vector to the values of the given `v`.

        Arguments
        - v: the vector whose values will be copied into this

        Returns
        - this
        """
        ...


    def set(self, v: "Vector4dc") -> "Vector4i":
        """
        Set this vector to the values of v using RoundingMode.TRUNCATE rounding.
        
        Note that due to the given vector `v` storing the components
        in double-precision, there is the possibility to lose precision.

        Arguments
        - v: the vector to copy from

        Returns
        - this
        """
        ...


    def set(self, v: "Vector4dc", mode: int) -> "Vector4i":
        """
        Set this vector to the values of v using the given RoundingMode.
        
        Note that due to the given vector `v` storing the components
        in double-precision, there is the possibility to lose precision.

        Arguments
        - v: the vector to copy from
        - mode: the RoundingMode to use

        Returns
        - this
        """
        ...


    def set(self, v: "Vector4fc", mode: int) -> "Vector4i":
        """
        Set this vector to the values of v using the given RoundingMode.
        
        Note that due to the given vector `v` storing the components
        in double-precision, there is the possibility to lose precision.

        Arguments
        - v: the vector to copy from
        - mode: the RoundingMode to use

        Returns
        - this
        """
        ...


    def set(self, v: "Vector3ic", w: int) -> "Vector4i":
        """
        Set the first three components of this to the components of
        `v` and the last component to `w`.

        Arguments
        - v: the Vector3ic to copy
        - w: the w component

        Returns
        - this
        """
        ...


    def set(self, v: "Vector2ic", z: int, w: int) -> "Vector4i":
        """
        Sets the first two components of this to the components of given
        `v` and last two components to the given `z`, and
        `w`.

        Arguments
        - v: the Vector2ic
        - z: the z component
        - w: the w component

        Returns
        - this
        """
        ...


    def set(self, s: int) -> "Vector4i":
        """
        Set the x, y, z, and w components to the supplied value.

        Arguments
        - s: the value of all four components

        Returns
        - this
        """
        ...


    def set(self, x: int, y: int, z: int, w: int) -> "Vector4i":
        """
        Set the x, y, z, and w components to the supplied values.

        Arguments
        - x: the x component
        - y: the y component
        - z: the z component
        - w: the w component

        Returns
        - this
        """
        ...


    def set(self, xyzw: list[int]) -> "Vector4i":
        """
        Set the four components of this vector to the first four elements of the given array.

        Arguments
        - xyzw: the array containing at least four elements

        Returns
        - this
        """
        ...


    def set(self, buffer: "ByteBuffer") -> "Vector4i":
        """
        Read this vector from the supplied ByteBuffer at the current
        buffer ByteBuffer.position() position.
        
        This method will not increment the position of the given ByteBuffer.
        
        In order to specify the offset into the ByteBuffer at which the vector is
        read, use .set(int, ByteBuffer), taking the absolute position as
        parameter.

        Arguments
        - buffer: values will be read in `x, y, z, w` order

        Returns
        - this

        See
        - .set(int, ByteBuffer)
        """
        ...


    def set(self, index: int, buffer: "ByteBuffer") -> "Vector4i":
        """
        Read this vector from the supplied ByteBuffer starting at the
        specified absolute buffer position/index.
        
        This method will not increment the position of the given ByteBuffer.

        Arguments
        - index: the absolute position into the ByteBuffer
        - buffer: values will be read in `x, y, z, w` order

        Returns
        - this
        """
        ...


    def set(self, buffer: "IntBuffer") -> "Vector4i":
        """
        Read this vector from the supplied IntBuffer at the current
        buffer IntBuffer.position() position.
        
        This method will not increment the position of the given IntBuffer.
        
        In order to specify the offset into the IntBuffer at which the vector is
        read, use .set(int, IntBuffer), taking the absolute position as
        parameter.

        Arguments
        - buffer: values will be read in `x, y, z, w` order

        Returns
        - this

        See
        - .set(int, IntBuffer)
        """
        ...


    def set(self, index: int, buffer: "IntBuffer") -> "Vector4i":
        """
        Read this vector from the supplied IntBuffer starting at the
        specified absolute buffer position/index.
        
        This method will not increment the position of the given IntBuffer.

        Arguments
        - index: the absolute position into the IntBuffer
        - buffer: values will be read in `x, y, z, w` order

        Returns
        - this
        """
        ...


    def setFromAddress(self, address: int) -> "Vector4i":
        """
        Set the values of this vector by reading 4 integer values from off-heap memory,
        starting at the given address.
        
        This method will throw an UnsupportedOperationException when JOML is used with `-Djoml.nounsafe`.
        
        *This method is unsafe as it can result in a crash of the JVM process when the specified address range does not belong to this process.*

        Arguments
        - address: the off-heap memory address to read the vector values from

        Returns
        - this
        """
        ...


    def get(self, component: int) -> int:
        ...


    def maxComponent(self) -> int:
        ...


    def minComponent(self) -> int:
        ...


    def setComponent(self, component: int, value: int) -> "Vector4i":
        """
        Set the value of the specified component of this vector.

        Arguments
        - component: the component whose value to set, within `[0..3]`
        - value: the value to set

        Returns
        - this

        Raises
        - IllegalArgumentException: if `component` is not within `[0..3]`
        """
        ...


    def get(self, buffer: "IntBuffer") -> "IntBuffer":
        ...


    def get(self, index: int, buffer: "IntBuffer") -> "IntBuffer":
        ...


    def get(self, buffer: "ByteBuffer") -> "ByteBuffer":
        ...


    def get(self, index: int, buffer: "ByteBuffer") -> "ByteBuffer":
        ...


    def getToAddress(self, address: int) -> "Vector4ic":
        ...


    def sub(self, v: "Vector4ic") -> "Vector4i":
        """
        Subtract the supplied vector from this one.

        Arguments
        - v: the vector to subtract

        Returns
        - this
        """
        ...


    def sub(self, x: int, y: int, z: int, w: int) -> "Vector4i":
        """
        Subtract `(x, y, z, w)` from this.

        Arguments
        - x: the x component to subtract
        - y: the y component to subtract
        - z: the z component to subtract
        - w: the w component to subtract

        Returns
        - this
        """
        ...


    def sub(self, v: "Vector4ic", dest: "Vector4i") -> "Vector4i":
        ...


    def sub(self, x: int, y: int, z: int, w: int, dest: "Vector4i") -> "Vector4i":
        ...


    def add(self, v: "Vector4ic") -> "Vector4i":
        """
        Add the supplied vector to this one.

        Arguments
        - v: the vector to add

        Returns
        - this
        """
        ...


    def add(self, v: "Vector4ic", dest: "Vector4i") -> "Vector4i":
        ...


    def add(self, x: int, y: int, z: int, w: int) -> "Vector4i":
        """
        Increment the components of this vector by the given values.

        Arguments
        - x: the x component to add
        - y: the y component to add
        - z: the z component to add
        - w: the w component to add

        Returns
        - this
        """
        ...


    def add(self, x: int, y: int, z: int, w: int, dest: "Vector4i") -> "Vector4i":
        ...


    def mul(self, v: "Vector4ic") -> "Vector4i":
        """
        Multiply this Vector4i component-wise by another Vector4i.

        Arguments
        - v: the other vector

        Returns
        - this
        """
        ...


    def mul(self, v: "Vector4ic", dest: "Vector4i") -> "Vector4i":
        ...


    def div(self, v: "Vector4ic") -> "Vector4i":
        """
        Divide this Vector4i component-wise by another Vector4i.

        Arguments
        - v: the vector to divide by

        Returns
        - this
        """
        ...


    def div(self, v: "Vector4ic", dest: "Vector4i") -> "Vector4i":
        ...


    def mul(self, scalar: int) -> "Vector4i":
        """
        Multiply all components of this vector by the given scalar
        value.

        Arguments
        - scalar: the scalar to multiply by

        Returns
        - this
        """
        ...


    def mul(self, scalar: int, dest: "Vector4i") -> "Vector4i":
        ...


    def div(self, scalar: float) -> "Vector4i":
        """
        Divide all components of this vector by the given scalar value.

        Arguments
        - scalar: the scalar to divide by

        Returns
        - this
        """
        ...


    def div(self, scalar: float, dest: "Vector4i") -> "Vector4i":
        ...


    def div(self, scalar: int) -> "Vector4i":
        """
        Divide all components of this vector by the given scalar value.

        Arguments
        - scalar: the scalar to divide by

        Returns
        - this
        """
        ...


    def div(self, scalar: int, dest: "Vector4i") -> "Vector4i":
        ...


    def lengthSquared(self) -> int:
        ...


    @staticmethod
    def lengthSquared(x: int, y: int, z: int, w: int) -> int:
        """
        Get the length squared of a 4-dimensional single-precision vector.

        Arguments
        - x: The vector's x component
        - y: The vector's y component
        - z: The vector's z component
        - w: The vector's w component

        Returns
        - the length squared of the given vector
        """
        ...


    def length(self) -> float:
        ...


    @staticmethod
    def length(x: int, y: int, z: int, w: int) -> float:
        """
        Get the length of a 4-dimensional single-precision vector.

        Arguments
        - x: The vector's x component
        - y: The vector's y component
        - z: The vector's z component
        - w: The vector's w component

        Returns
        - the length squared of the given vector
        """
        ...


    def distance(self, v: "Vector4ic") -> float:
        ...


    def distance(self, x: int, y: int, z: int, w: int) -> float:
        ...


    def gridDistance(self, v: "Vector4ic") -> int:
        ...


    def gridDistance(self, x: int, y: int, z: int, w: int) -> int:
        ...


    def distanceSquared(self, v: "Vector4ic") -> int:
        ...


    def distanceSquared(self, x: int, y: int, z: int, w: int) -> int:
        ...


    @staticmethod
    def distance(x1: int, y1: int, z1: int, w1: int, x2: int, y2: int, z2: int, w2: int) -> float:
        """
        Return the distance between `(x1, y1, z1, w1)` and `(x2, y2, z2, w2)`.

        Arguments
        - x1: the x component of the first vector
        - y1: the y component of the first vector
        - z1: the z component of the first vector
        - w1: the w component of the first vector
        - x2: the x component of the second vector
        - y2: the y component of the second vector
        - z2: the z component of the second vector
        - w2: the 2 component of the second vector

        Returns
        - the euclidean distance
        """
        ...


    @staticmethod
    def distanceSquared(x1: int, y1: int, z1: int, w1: int, x2: int, y2: int, z2: int, w2: int) -> int:
        """
        Return the squared distance between `(x1, y1, z1, w1)` and `(x2, y2, z2, w2)`.

        Arguments
        - x1: the x component of the first vector
        - y1: the y component of the first vector
        - z1: the z component of the first vector
        - w1: the w component of the first vector
        - x2: the x component of the second vector
        - y2: the y component of the second vector
        - z2: the z component of the second vector
        - w2: the w component of the second vector

        Returns
        - the euclidean distance squared
        """
        ...


    def dot(self, v: "Vector4ic") -> int:
        ...


    def zero(self) -> "Vector4i":
        """
        Set all components to zero.

        Returns
        - this
        """
        ...


    def negate(self) -> "Vector4i":
        """
        Negate this vector.

        Returns
        - this
        """
        ...


    def negate(self, dest: "Vector4i") -> "Vector4i":
        ...


    def toString(self) -> str:
        """
        Return a string representation of this vector.
        
        This method creates a new DecimalFormat on every invocation with the format string "`0.000E0;-`".

        Returns
        - the string representation
        """
        ...


    def toString(self, formatter: "NumberFormat") -> str:
        """
        Return a string representation of this vector by formatting the vector components with the given NumberFormat.

        Arguments
        - formatter: the NumberFormat used to format the vector components with

        Returns
        - the string representation
        """
        ...


    def writeExternal(self, out: "ObjectOutput") -> None:
        ...


    def readExternal(self, in: "ObjectInput") -> None:
        ...


    def min(self, v: "Vector4ic") -> "Vector4i":
        """
        Set the components of this vector to be the component-wise minimum of this and the other vector.

        Arguments
        - v: the other vector

        Returns
        - this
        """
        ...


    def min(self, v: "Vector4ic", dest: "Vector4i") -> "Vector4i":
        ...


    def max(self, v: "Vector4ic") -> "Vector4i":
        """
        Set the components of this vector to be the component-wise maximum of this and the other vector.

        Arguments
        - v: the other vector

        Returns
        - this
        """
        ...


    def max(self, v: "Vector4ic", dest: "Vector4i") -> "Vector4i":
        ...


    def absolute(self) -> "Vector4i":
        """
        Compute the absolute of each of this vector's components.

        Returns
        - this
        """
        ...


    def absolute(self, dest: "Vector4i") -> "Vector4i":
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def equals(self, x: int, y: int, z: int, w: int) -> bool:
        ...


    def clone(self) -> "Object":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.SeaPickle

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Waterlogged
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class SeaPickle(Waterlogged):
    """
    'pickles' indicates the number of pickles in this block.
    """

    def getPickles(self) -> int:
        """
        Gets the value of the 'pickles' property.

        Returns
        - the 'pickles' value
        """
        ...


    def setPickles(self, pickles: int) -> None:
        """
        Sets the value of the 'pickles' property.

        Arguments
        - pickles: the new 'pickles' value
        """
        ...


    def getMinimumPickles(self) -> int:
        """
        Gets the minimum allowed value of the 'pickles' property.

        Returns
        - the minimum 'pickles' value
        """
        ...


    def getMaximumPickles(self) -> int:
        """
        Gets the maximum allowed value of the 'pickles' property.

        Returns
        - the maximum 'pickles' value
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.HashBasedTable

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Supplier
from com.google.common.collect import *
from java.io import Serializable
from typing import Any, Callable, Iterable, Tuple


class HashBasedTable(StandardTable):
    """
    Implementation of Table using linked hash tables. This guarantees predictable iteration
    order of the various views.
    
    The views returned by .column, .columnKeySet(), and .columnMap() have
    iterators that don't support `remove()`. Otherwise, all optional operations are supported.
    Null row keys, columns keys, and values are not supported.
    
    Lookups by row key are often faster than lookups by column key, because the data is stored in
    a `Map<R, Map<C, V>>`. A method call like `column(columnKey).get(rowKey)` still runs
    quickly, since the row key is provided. However, `column(columnKey).size()` takes longer,
    since an iteration across all row keys occurs.
    
    Note that this implementation is not synchronized. If multiple threads access this table
    concurrently and one of the threads modifies the table, it must be synchronized externally.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#table">`Table`</a>.

    Author(s)
    - Jared Levy

    Since
    - 7.0
    """

    @staticmethod
    def create() -> "HashBasedTable"["R", "C", "V"]:
        """
        Creates an empty `HashBasedTable`.
        """
        ...


    @staticmethod
    def create(expectedRows: int, expectedCellsPerRow: int) -> "HashBasedTable"["R", "C", "V"]:
        """
        Creates an empty `HashBasedTable` with the specified map sizes.

        Arguments
        - expectedRows: the expected number of distinct row keys
        - expectedCellsPerRow: the expected number of column key / value mappings in each row

        Raises
        - IllegalArgumentException: if `expectedRows` or `expectedCellsPerRow` is
            negative
        """
        ...


    @staticmethod
    def create(table: "Table"["R", "C", "V"]) -> "HashBasedTable"["R", "C", "V"]:
        """
        Creates a `HashBasedTable` with the same mappings as the specified table.

        Arguments
        - table: the table to copy

        Raises
        - NullPointerException: if any of the row keys, column keys, or values in `table` is
            null
        """
        ...



"""
Python module generated from Java source file java.nio.file.attribute.BasicFileAttributes

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.nio.file.attribute import *
from typing import Any, Callable, Iterable, Tuple


class BasicFileAttributes:

    def lastModifiedTime(self) -> "FileTime":
        """
        Returns the time of last modification.
        
         If the file system implementation does not support a time stamp
        to indicate the time of last modification then this method returns an
        implementation specific default value, typically a `FileTime`
        representing the epoch (1970-01-01T00:00:00Z).

        Returns
        - a `FileTime` representing the time the file was last
                 modified
        """
        ...


    def lastAccessTime(self) -> "FileTime":
        """
        Returns the time of last access.
        
         If the file system implementation does not support a time stamp
        to indicate the time of last access then this method returns
        an implementation specific default value, typically the .lastModifiedTime() last-modified-time or a `FileTime`
        representing the epoch (1970-01-01T00:00:00Z).

        Returns
        - a `FileTime` representing the time of last access
        """
        ...


    def creationTime(self) -> "FileTime":
        """
        Returns the creation time. The creation time is the time that the file
        was created.
        
         If the file system implementation does not support a time stamp
        to indicate the time when the file was created then this method returns
        an implementation specific default value, typically the .lastModifiedTime() last-modified-time or a `FileTime`
        representing the epoch (1970-01-01T00:00:00Z).

        Returns
        - a `FileTime` representing the time the file was created
        """
        ...


    def isRegularFile(self) -> bool:
        """
        Tells whether the file is a regular file with opaque content.

        Returns
        - `True` if the file is a regular file with opaque content
        """
        ...


    def isDirectory(self) -> bool:
        """
        Tells whether the file is a directory.

        Returns
        - `True` if the file is a directory
        """
        ...


    def isSymbolicLink(self) -> bool:
        """
        Tells whether the file is a symbolic link.

        Returns
        - `True` if the file is a symbolic link
        """
        ...


    def isOther(self) -> bool:
        """
        Tells whether the file is something other than a regular file, directory,
        or symbolic link.

        Returns
        - `True` if the file something other than a regular file,
                directory or symbolic link
        """
        ...


    def size(self) -> int:
        """
        Returns the size of the file (in bytes). The size may differ from the
        actual size on the file system due to compression, support for sparse
        files, or other reasons. The size of files that are not .isRegularFile regular files is implementation specific and
        therefore unspecified.

        Returns
        - the file size, in bytes
        """
        ...


    def fileKey(self) -> "Object":
        """
        Returns an object that uniquely identifies the given file, or `null` if a file key is not available. On some platforms or file systems
        it is possible to use an identifier, or a combination of identifiers to
        uniquely identify a file. Such identifiers are important for operations
        such as file tree traversal in file systems that support <a
        href="../package-summary.html#links">symbolic links</a> or file systems
        that allow a file to be an entry in more than one directory. On UNIX file
        systems, for example, the *device ID* and *inode* are
        commonly used for such purposes.
        
         The file key returned by this method can only be guaranteed to be
        unique if the file system and files remain static. Whether a file system
        re-uses identifiers after a file is deleted is implementation dependent and
        therefore unspecified.
        
         File keys returned by this method can be compared for equality and are
        suitable for use in collections. If the file system and files remain static,
        and two files are the java.nio.file.Files.isSameFile same with
        non-`null` file keys, then their file keys are equal.

        Returns
        - an object that uniquely identifies the given file, or `null`

        See
        - java.nio.file.Files.walkFileTree
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.GraphConnections

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class GraphConnections:
    """
    An interface for representing and manipulating an origin node's adjacent nodes and edge values in
    a Graph.
    
    Type `<N>`: Node parameter type
    
    Type `<V>`: Value parameter type

    Author(s)
    - James Sexton
    """

    def adjacentNodes(self) -> set["N"]:
        ...


    def predecessors(self) -> set["N"]:
        ...


    def successors(self) -> set["N"]:
        ...


    def incidentEdgeIterator(self, thisNode: "N") -> Iterator["EndpointPair"["N"]]:
        """
        Returns an iterator over the incident edges.

        Arguments
        - thisNode: The node that this all of the connections in this class are connected to.
        """
        ...


    def value(self, node: "N") -> "V":
        """
        Returns the value associated with the edge connecting the origin node to `node`, or null
        if there is no such edge.
        """
        ...


    def removePredecessor(self, node: "N") -> None:
        """
        Remove `node` from the set of predecessors.
        """
        ...


    def removeSuccessor(self, node: "N") -> "V":
        """
        Remove `node` from the set of successors. Returns the value previously associated with
        the edge connecting the two nodes.
        """
        ...


    def addPredecessor(self, node: "N", value: "V") -> None:
        """
        Add `node` as a predecessor to the origin node. In the case of an undirected graph, it
        also becomes a successor. Associates `value` with the edge connecting the two nodes.
        """
        ...


    def addSuccessor(self, node: "N", value: "V") -> "V":
        """
        Add `node` as a successor to the origin node. In the case of an undirected graph, it also
        becomes a predecessor. Associates `value` with the edge connecting the two nodes. Returns
        the value previously associated with the edge connecting the two nodes.
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.AnvilInventory

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import *
from org.bukkit.inventory.view import AnvilView
from typing import Any, Callable, Iterable, Tuple


class AnvilInventory(Inventory):
    """
    Interface to the inventory of an Anvil.
    """

    def getRenameText(self) -> str:
        """
        Get the name to be applied to the repaired item. An empty string denotes
        the default item name.

        Returns
        - the rename text

        Deprecated
        - use AnvilView.getRenameText().
        """
        ...


    def getRepairCostAmount(self) -> int:
        """
        Get the item cost (in amount) to complete the current repair.

        Returns
        - the amount

        Deprecated
        - use AnvilView.getRepairItemCountCost().
        """
        ...


    def setRepairCostAmount(self, amount: int) -> None:
        """
        Set the item cost (in amount) to complete the current repair.

        Arguments
        - amount: the amount

        Deprecated
        - use AnvilView.setRepairItemCountCost(int).
        """
        ...


    def getRepairCost(self) -> int:
        """
        Get the experience cost (in levels) to complete the current repair.

        Returns
        - the experience cost

        Deprecated
        - use AnvilView.getRepairCost().
        """
        ...


    def setRepairCost(self, levels: int) -> None:
        """
        Set the experience cost (in levels) to complete the current repair.

        Arguments
        - levels: the experience cost

        Deprecated
        - use AnvilView.setRepairCost(int).
        """
        ...


    def getMaximumRepairCost(self) -> int:
        """
        Get the maximum experience cost (in levels) to be allowed by the current
        repair. If the result of .getRepairCost() exceeds the returned
        value, the repair result will be air to due being "too expensive".
        
        By default, this level is set to 40. Players in creative mode ignore the
        maximum repair cost.

        Returns
        - the maximum experience cost

        Deprecated
        - use AnvilView.getMaximumRepairCost().
        """
        ...


    def setMaximumRepairCost(self, levels: int) -> None:
        """
        Set the maximum experience cost (in levels) to be allowed by the current
        repair. The default value set by vanilla Minecraft is 40.

        Arguments
        - levels: the maximum experience cost

        Deprecated
        - use AnvilView.setMaximumRepairCost(int).
        """
        ...



"""
Python module generated from Java source file java.util.BitSet

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import *
from java.util.function import IntConsumer
from java.util.stream import IntStream
from java.util.stream import StreamSupport
from typing import Any, Callable, Iterable, Tuple


class BitSet(Cloneable, Serializable):
    """
    This class implements a vector of bits that grows as needed. Each
    component of the bit set has a `boolean` value. The
    bits of a `BitSet` are indexed by nonnegative integers.
    Individual indexed bits can be examined, set, or cleared. One
    `BitSet` may be used to modify the contents of another
    `BitSet` through logical AND, logical inclusive OR, and
    logical exclusive OR operations.
    
    By default, all bits in the set initially have the value
    `False`.
    
    Every bit set has a current size, which is the number of bits
    of space currently in use by the bit set. Note that the size is
    related to the implementation of a bit set, so it may change with
    implementation. The length of a bit set relates to logical length
    of a bit set and is defined independently of implementation.
    
    Unless otherwise noted, passing a null parameter to any of the
    methods in a `BitSet` will result in a
    `NullPointerException`.
    
    A `BitSet` is not safe for multithreaded use without
    external synchronization.

    Author(s)
    - Martin Buchholz

    Since
    - 1.0
    """

    def __init__(self):
        """
        Creates a new bit set. All bits are initially `False`.
        """
        ...


    def __init__(self, nbits: int):
        """
        Creates a bit set whose initial size is large enough to explicitly
        represent bits with indices in the range `0` through
        `nbits-1`. All bits are initially `False`.

        Arguments
        - nbits: the initial size of the bit set

        Raises
        - NegativeArraySizeException: if the specified initial size
                is negative
        """
        ...


    @staticmethod
    def valueOf(longs: list[int]) -> "BitSet":
        """
        Returns a new bit set containing all the bits in the given long array.
        
        More precisely,
        `BitSet.valueOf(longs).get(n) == ((longs[n/64] & (1L<<(n%64))) != 0)`
        for all `n < 64 * longs.length`.
        
        This method is equivalent to
        `BitSet.valueOf(LongBuffer.wrap(longs))`.

        Arguments
        - longs: a long array containing a little-endian representation
               of a sequence of bits to be used as the initial bits of the
               new bit set

        Returns
        - a `BitSet` containing all the bits in the long array

        Since
        - 1.7
        """
        ...


    @staticmethod
    def valueOf(lb: "LongBuffer") -> "BitSet":
        """
        Returns a new bit set containing all the bits in the given long
        buffer between its position and limit.
        
        More precisely,
        `BitSet.valueOf(lb).get(n) == ((lb.get(lb.position()+n/64) & (1L<<(n%64))) != 0)`
        for all `n < 64 * lb.remaining()`.
        
        The long buffer is not modified by this method, and no
        reference to the buffer is retained by the bit set.

        Arguments
        - lb: a long buffer containing a little-endian representation
               of a sequence of bits between its position and limit, to be
               used as the initial bits of the new bit set

        Returns
        - a `BitSet` containing all the bits in the buffer in the
                specified range

        Since
        - 1.7
        """
        ...


    @staticmethod
    def valueOf(bytes: list[int]) -> "BitSet":
        """
        Returns a new bit set containing all the bits in the given byte array.
        
        More precisely,
        `BitSet.valueOf(bytes).get(n) == ((bytes[n/8] & (1<<(n%8))) != 0)`
        for all `n <  8 * bytes.length`.
        
        This method is equivalent to
        `BitSet.valueOf(ByteBuffer.wrap(bytes))`.

        Arguments
        - bytes: a byte array containing a little-endian
               representation of a sequence of bits to be used as the
               initial bits of the new bit set

        Returns
        - a `BitSet` containing all the bits in the byte array

        Since
        - 1.7
        """
        ...


    @staticmethod
    def valueOf(bb: "ByteBuffer") -> "BitSet":
        """
        Returns a new bit set containing all the bits in the given byte
        buffer between its position and limit.
        
        More precisely,
        `BitSet.valueOf(bb).get(n) == ((bb.get(bb.position()+n/8) & (1<<(n%8))) != 0)`
        for all `n < 8 * bb.remaining()`.
        
        The byte buffer is not modified by this method, and no
        reference to the buffer is retained by the bit set.

        Arguments
        - bb: a byte buffer containing a little-endian representation
               of a sequence of bits between its position and limit, to be
               used as the initial bits of the new bit set

        Returns
        - a `BitSet` containing all the bits in the buffer in the
                specified range

        Since
        - 1.7
        """
        ...


    def toByteArray(self) -> list[int]:
        """
        Returns a new byte array containing all the bits in this bit set.
        
        More precisely, if
        `byte[] bytes = s.toByteArray();`
        then `bytes.length == (s.length()+7)/8` and
        `s.get(n) == ((bytes[n/8] & (1<<(n%8))) != 0)`
        for all `n < 8 * bytes.length`.

        Returns
        - a byte array containing a little-endian representation
                of all the bits in this bit set

        Since
        - 1.7
        """
        ...


    def toLongArray(self) -> list[int]:
        """
        Returns a new long array containing all the bits in this bit set.
        
        More precisely, if
        `long[] longs = s.toLongArray();`
        then `longs.length == (s.length()+63)/64` and
        `s.get(n) == ((longs[n/64] & (1L<<(n%64))) != 0)`
        for all `n < 64 * longs.length`.

        Returns
        - a long array containing a little-endian representation
                of all the bits in this bit set

        Since
        - 1.7
        """
        ...


    def flip(self, bitIndex: int) -> None:
        """
        Sets the bit at the specified index to the complement of its
        current value.

        Arguments
        - bitIndex: the index of the bit to flip

        Raises
        - IndexOutOfBoundsException: if the specified index is negative

        Since
        - 1.4
        """
        ...


    def flip(self, fromIndex: int, toIndex: int) -> None:
        """
        Sets each bit from the specified `fromIndex` (inclusive) to the
        specified `toIndex` (exclusive) to the complement of its current
        value.

        Arguments
        - fromIndex: index of the first bit to flip
        - toIndex: index after the last bit to flip

        Raises
        - IndexOutOfBoundsException: if `fromIndex` is negative,
                or `toIndex` is negative, or `fromIndex` is
                larger than `toIndex`

        Since
        - 1.4
        """
        ...


    def set(self, bitIndex: int) -> None:
        """
        Sets the bit at the specified index to `True`.

        Arguments
        - bitIndex: a bit index

        Raises
        - IndexOutOfBoundsException: if the specified index is negative

        Since
        - 1.0
        """
        ...


    def set(self, bitIndex: int, value: bool) -> None:
        """
        Sets the bit at the specified index to the specified value.

        Arguments
        - bitIndex: a bit index
        - value: a boolean value to set

        Raises
        - IndexOutOfBoundsException: if the specified index is negative

        Since
        - 1.4
        """
        ...


    def set(self, fromIndex: int, toIndex: int) -> None:
        """
        Sets the bits from the specified `fromIndex` (inclusive) to the
        specified `toIndex` (exclusive) to `True`.

        Arguments
        - fromIndex: index of the first bit to be set
        - toIndex: index after the last bit to be set

        Raises
        - IndexOutOfBoundsException: if `fromIndex` is negative,
                or `toIndex` is negative, or `fromIndex` is
                larger than `toIndex`

        Since
        - 1.4
        """
        ...


    def set(self, fromIndex: int, toIndex: int, value: bool) -> None:
        """
        Sets the bits from the specified `fromIndex` (inclusive) to the
        specified `toIndex` (exclusive) to the specified value.

        Arguments
        - fromIndex: index of the first bit to be set
        - toIndex: index after the last bit to be set
        - value: value to set the selected bits to

        Raises
        - IndexOutOfBoundsException: if `fromIndex` is negative,
                or `toIndex` is negative, or `fromIndex` is
                larger than `toIndex`

        Since
        - 1.4
        """
        ...


    def clear(self, bitIndex: int) -> None:
        """
        Sets the bit specified by the index to `False`.

        Arguments
        - bitIndex: the index of the bit to be cleared

        Raises
        - IndexOutOfBoundsException: if the specified index is negative

        Since
        - 1.0
        """
        ...


    def clear(self, fromIndex: int, toIndex: int) -> None:
        """
        Sets the bits from the specified `fromIndex` (inclusive) to the
        specified `toIndex` (exclusive) to `False`.

        Arguments
        - fromIndex: index of the first bit to be cleared
        - toIndex: index after the last bit to be cleared

        Raises
        - IndexOutOfBoundsException: if `fromIndex` is negative,
                or `toIndex` is negative, or `fromIndex` is
                larger than `toIndex`

        Since
        - 1.4
        """
        ...


    def clear(self) -> None:
        """
        Sets all of the bits in this BitSet to `False`.

        Since
        - 1.4
        """
        ...


    def get(self, bitIndex: int) -> bool:
        """
        Returns the value of the bit with the specified index. The value
        is `True` if the bit with the index `bitIndex`
        is currently set in this `BitSet`; otherwise, the result
        is `False`.

        Arguments
        - bitIndex: the bit index

        Returns
        - the value of the bit with the specified index

        Raises
        - IndexOutOfBoundsException: if the specified index is negative
        """
        ...


    def get(self, fromIndex: int, toIndex: int) -> "BitSet":
        """
        Returns a new `BitSet` composed of bits from this `BitSet`
        from `fromIndex` (inclusive) to `toIndex` (exclusive).

        Arguments
        - fromIndex: index of the first bit to include
        - toIndex: index after the last bit to include

        Returns
        - a new `BitSet` from a range of this `BitSet`

        Raises
        - IndexOutOfBoundsException: if `fromIndex` is negative,
                or `toIndex` is negative, or `fromIndex` is
                larger than `toIndex`

        Since
        - 1.4
        """
        ...


    def nextSetBit(self, fromIndex: int) -> int:
        """
        Returns the index of the first bit that is set to `True`
        that occurs on or after the specified starting index. If no such
        bit exists then `-1` is returned.
        
        To iterate over the `True` bits in a `BitSet`,
        use the following loop:
        
         ``` `for (int i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i+1)) {
            // operate on index i here
            if (i == Integer.MAX_VALUE) {
                break; // or (i+1) would overflow`
        }}```

        Arguments
        - fromIndex: the index to start checking from (inclusive)

        Returns
        - the index of the next set bit, or `-1` if there
                is no such bit

        Raises
        - IndexOutOfBoundsException: if the specified index is negative

        Since
        - 1.4
        """
        ...


    def nextClearBit(self, fromIndex: int) -> int:
        """
        Returns the index of the first bit that is set to `False`
        that occurs on or after the specified starting index.

        Arguments
        - fromIndex: the index to start checking from (inclusive)

        Returns
        - the index of the next clear bit

        Raises
        - IndexOutOfBoundsException: if the specified index is negative

        Since
        - 1.4
        """
        ...


    def previousSetBit(self, fromIndex: int) -> int:
        """
        Returns the index of the nearest bit that is set to `True`
        that occurs on or before the specified starting index.
        If no such bit exists, or if `-1` is given as the
        starting index, then `-1` is returned.
        
        To iterate over the `True` bits in a `BitSet`,
        use the following loop:
        
         ``` `for (int i = bs.length(); (i = bs.previousSetBit(i-1)) >= 0; ) {
            // operate on index i here`}```

        Arguments
        - fromIndex: the index to start checking from (inclusive)

        Returns
        - the index of the previous set bit, or `-1` if there
                is no such bit

        Raises
        - IndexOutOfBoundsException: if the specified index is less
                than `-1`

        Since
        - 1.7
        """
        ...


    def previousClearBit(self, fromIndex: int) -> int:
        """
        Returns the index of the nearest bit that is set to `False`
        that occurs on or before the specified starting index.
        If no such bit exists, or if `-1` is given as the
        starting index, then `-1` is returned.

        Arguments
        - fromIndex: the index to start checking from (inclusive)

        Returns
        - the index of the previous clear bit, or `-1` if there
                is no such bit

        Raises
        - IndexOutOfBoundsException: if the specified index is less
                than `-1`

        Since
        - 1.7
        """
        ...


    def length(self) -> int:
        """
        Returns the "logical size" of this `BitSet`: the index of
        the highest set bit in the `BitSet` plus one. Returns zero
        if the `BitSet` contains no set bits.

        Returns
        - the logical size of this `BitSet`

        Since
        - 1.2
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns True if this `BitSet` contains no bits that are set
        to `True`.

        Returns
        - boolean indicating whether this `BitSet` is empty

        Since
        - 1.4
        """
        ...


    def intersects(self, set: "BitSet") -> bool:
        """
        Returns True if the specified `BitSet` has any bits set to
        `True` that are also set to `True` in this `BitSet`.

        Arguments
        - set: `BitSet` to intersect with

        Returns
        - boolean indicating whether this `BitSet` intersects
                the specified `BitSet`

        Since
        - 1.4
        """
        ...


    def cardinality(self) -> int:
        """
        Returns the number of bits set to `True` in this `BitSet`.

        Returns
        - the number of bits set to `True` in this `BitSet`

        Since
        - 1.4
        """
        ...


    def and(self, set: "BitSet") -> None:
        """
        Performs a logical **AND** of this target bit set with the
        argument bit set. This bit set is modified so that each bit in it
        has the value `True` if and only if it both initially
        had the value `True` and the corresponding bit in the
        bit set argument also had the value `True`.

        Arguments
        - set: a bit set
        """
        ...


    def or(self, set: "BitSet") -> None:
        """
        Performs a logical **OR** of this bit set with the bit set
        argument. This bit set is modified so that a bit in it has the
        value `True` if and only if it either already had the
        value `True` or the corresponding bit in the bit set
        argument has the value `True`.

        Arguments
        - set: a bit set
        """
        ...


    def xor(self, set: "BitSet") -> None:
        """
        Performs a logical **XOR** of this bit set with the bit set
        argument. This bit set is modified so that a bit in it has the
        value `True` if and only if one of the following
        statements holds:
        
        - The bit initially has the value `True`, and the
            corresponding bit in the argument has the value `False`.
        - The bit initially has the value `False`, and the
            corresponding bit in the argument has the value `True`.

        Arguments
        - set: a bit set
        """
        ...


    def andNot(self, set: "BitSet") -> None:
        """
        Clears all of the bits in this `BitSet` whose corresponding
        bit is set in the specified `BitSet`.

        Arguments
        - set: the `BitSet` with which to mask this
                `BitSet`

        Since
        - 1.2
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code value for this bit set. The hash code depends
        only on which bits are set within this `BitSet`.
        
        The hash code is defined to be the result of the following
        calculation:
         ``` `public int hashCode() {
            long h = 1234;
            long[] words = toLongArray();
            for (int i = words.length; --i >= 0; )
                h ^= words[i] * (i + 1);
            return (int)((h >> 32) ^ h);`}```
        Note that the hash code changes if the set of bits is altered.

        Returns
        - the hash code value for this bit set
        """
        ...


    def size(self) -> int:
        """
        Returns the number of bits of space actually in use by this
        `BitSet` to represent bit values.
        The maximum element in the set is the size - 1st element.

        Returns
        - the number of bits currently in this bit set
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares this object against the specified object.
        The result is `True` if and only if the argument is
        not `null` and is a `BitSet` object that has
        exactly the same set of bits set to `True` as this bit
        set. That is, for every nonnegative `int` index `k`,
        ```((BitSet)obj).get(k) == this.get(k)```
        must be True. The current sizes of the two bit sets are not compared.

        Arguments
        - obj: the object to compare with

        Returns
        - `True` if the objects are the same;
                `False` otherwise

        See
        - .size()
        """
        ...


    def clone(self) -> "Object":
        """
        Cloning this `BitSet` produces a new `BitSet`
        that is equal to it.
        The clone of the bit set is another bit set that has exactly the
        same bits set to `True` as this bit set.

        Returns
        - a clone of this bit set

        See
        - .size()
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation of this bit set. For every index
        for which this `BitSet` contains a bit in the set
        state, the decimal representation of that index is included in
        the result. Such indices are listed in order from lowest to
        highest, separated by ",&nbsp;" (a comma and a space) and
        surrounded by braces, resulting in the usual mathematical
        notation for a set of integers.
        
        Example:
        ```
        BitSet drPepper = new BitSet();```
        Now `drPepper.toString()` returns "`{`}".
        ```
        drPepper.set(2);```
        Now `drPepper.toString()` returns "`{2`}".
        ```
        drPepper.set(4);
        drPepper.set(10);```
        Now `drPepper.toString()` returns "`{2, 4, 10`}".

        Returns
        - a string representation of this bit set
        """
        ...


    def stream(self) -> "IntStream":
        """
        Returns a stream of indices for which this `BitSet`
        contains a bit in the set state. The indices are returned
        in order, from lowest to highest. The size of the stream
        is the number of bits in the set state, equal to the value
        returned by the .cardinality() method.
        
        The stream binds to this bit set when the terminal stream operation
        commences (specifically, the spliterator for the stream is
        <a href="Spliterator.html#binding">*late-binding*</a>).  If the
        bit set is modified during that operation then the result is undefined.

        Returns
        - a stream of integers representing set indices

        Since
        - 1.8
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Axolotl

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Axolotl(Animals):
    """
    An Axolotl.
    """

    def isPlayingDead(self) -> bool:
        """
        Gets if this axolotl is playing dead.
        
        An axolotl may play dead when it is damaged underwater.

        Returns
        - playing dead status
        """
        ...


    def setPlayingDead(self, playingDead: bool) -> None:
        """
        Sets if this axolotl is playing dead.
        
        An axolotl may play dead when it is damaged underwater.

        Arguments
        - playingDead: playing dead status
        """
        ...


    def getVariant(self) -> "Variant":
        """
        Get the variant of this axolotl.

        Returns
        - axolotl variant
        """
        ...


    def setVariant(self, variant: "Variant") -> None:
        """
        Set the variant of this axolotl.

        Arguments
        - variant: axolotl variant
        """
        ...


    class Variant(Enum):
        """
        Represents the variant of a axolotl - ie its color.
        """

        LUCY = 0
        """
        Leucistic (pink) axolotl.
        """
        WILD = 1
        """
        Brown axolotl.
        """
        GOLD = 2
        """
        Gold axolotl.
        """
        CYAN = 3
        """
        Cyan axolotl.
        """
        BLUE = 4
        """
        Blue axolotl.
        """



"""
Python module generated from Java source file org.bukkit.Vibration

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from org.bukkit.block import Block
from org.bukkit.entity import Entity
from typing import Any, Callable, Iterable, Tuple


class Vibration:
    """
    Represents a vibration from a Skulk sensor.
    """

    def __init__(self, origin: "Location", destination: "Destination", arrivalTime: int):
        ...


    def getOrigin(self) -> "Location":
        """
        Get the origin of the vibration.

        Returns
        - origin
        """
        ...


    def getDestination(self) -> "Destination":
        """
        Get the vibration destination.

        Returns
        - destination
        """
        ...


    def getArrivalTime(self) -> int:
        """
        Get the vibration arrival time in ticks.

        Returns
        - arrival time
        """
        ...


    class Destination:

        class EntityDestination(Destination):

            def __init__(self, entity: "Entity"):
                ...


            def getEntity(self) -> "Entity":
                ...


        class BlockDestination(Destination):

            def __init__(self, block: "Location"):
                ...


            def __init__(self, block: "Block"):
                ...


            def getLocation(self) -> "Location":
                ...


            def getBlock(self) -> "Block":
                ...



"""
Python module generated from Java source file org.yaml.snakeyaml.parser.ParserImpl

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.DumperOptions import Version
from org.yaml.snakeyaml import LoaderOptions
from org.yaml.snakeyaml.comments import CommentType
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.events import AliasEvent
from org.yaml.snakeyaml.events import CommentEvent
from org.yaml.snakeyaml.events import DocumentEndEvent
from org.yaml.snakeyaml.events import DocumentStartEvent
from org.yaml.snakeyaml.events import Event
from org.yaml.snakeyaml.events import ImplicitTuple
from org.yaml.snakeyaml.events import MappingEndEvent
from org.yaml.snakeyaml.events import MappingStartEvent
from org.yaml.snakeyaml.events import ScalarEvent
from org.yaml.snakeyaml.events import SequenceEndEvent
from org.yaml.snakeyaml.events import SequenceStartEvent
from org.yaml.snakeyaml.events import StreamEndEvent
from org.yaml.snakeyaml.events import StreamStartEvent
from org.yaml.snakeyaml.nodes import Tag
from org.yaml.snakeyaml.parser import *
from org.yaml.snakeyaml.reader import StreamReader
from org.yaml.snakeyaml.scanner import Scanner
from org.yaml.snakeyaml.scanner import ScannerImpl
from org.yaml.snakeyaml.tokens import AliasToken
from org.yaml.snakeyaml.tokens import AnchorToken
from org.yaml.snakeyaml.tokens import BlockEntryToken
from org.yaml.snakeyaml.tokens import CommentToken
from org.yaml.snakeyaml.tokens import DirectiveToken
from org.yaml.snakeyaml.tokens import ScalarToken
from org.yaml.snakeyaml.tokens import StreamEndToken
from org.yaml.snakeyaml.tokens import StreamStartToken
from org.yaml.snakeyaml.tokens import TagToken
from org.yaml.snakeyaml.tokens import TagTuple
from org.yaml.snakeyaml.tokens import Token
from org.yaml.snakeyaml.util import ArrayStack
from typing import Any, Callable, Iterable, Tuple


class ParserImpl(Parser):
    """
    ```
    # The following YAML grammar is LL(1) and is parsed by a recursive descent
    parser.
    stream            ::= STREAM-START implicit_document? explicit_document* STREAM-END
    implicit_document ::= block_node DOCUMENT-END*
    explicit_document ::= DIRECTIVE* DOCUMENT-START block_node? DOCUMENT-END*
    block_node_or_indentless_sequence ::=
                          ALIAS
                          | properties (block_content | indentless_block_sequence)?
                          | block_content
                          | indentless_block_sequence
    block_node        ::= ALIAS
                          | properties block_content?
                          | block_content
    flow_node         ::= ALIAS
                          | properties flow_content?
                          | flow_content
    properties        ::= TAG ANCHOR? | ANCHOR TAG?
    block_content     ::= block_collection | flow_collection | SCALAR
    flow_content      ::= flow_collection | SCALAR
    block_collection  ::= block_sequence | block_mapping
    flow_collection   ::= flow_sequence | flow_mapping
    block_sequence    ::= BLOCK-SEQUENCE-START (BLOCK-ENTRY block_node?)* BLOCK-END
    indentless_sequence   ::= (BLOCK-ENTRY block_node?)+
    block_mapping     ::= BLOCK-MAPPING_START
                          ((KEY block_node_or_indentless_sequence?)?
                          (VALUE block_node_or_indentless_sequence?)?)*
                          BLOCK-END
    flow_sequence     ::= FLOW-SEQUENCE-START
                          (flow_sequence_entry FLOW-ENTRY)*
                          flow_sequence_entry?
                          FLOW-SEQUENCE-END
    flow_sequence_entry   ::= flow_node | KEY flow_node? (VALUE flow_node?)?
    flow_mapping      ::= FLOW-MAPPING-START
                          (flow_mapping_entry FLOW-ENTRY)*
                          flow_mapping_entry?
                          FLOW-MAPPING-END
    flow_mapping_entry    ::= flow_node | KEY flow_node? (VALUE flow_node?)?
    FIRST sets:
    stream: { STREAM-START }
    explicit_document: { DIRECTIVE DOCUMENT-START }
    implicit_document: FIRST(block_node)
    block_node: { ALIAS TAG ANCHOR SCALAR BLOCK-SEQUENCE-START BLOCK-MAPPING-START FLOW-SEQUENCE-START FLOW-MAPPING-START }
    flow_node: { ALIAS ANCHOR TAG SCALAR FLOW-SEQUENCE-START FLOW-MAPPING-START }
    block_content: { BLOCK-SEQUENCE-START BLOCK-MAPPING-START FLOW-SEQUENCE-START FLOW-MAPPING-START SCALAR }
    flow_content: { FLOW-SEQUENCE-START FLOW-MAPPING-START SCALAR }
    block_collection: { BLOCK-SEQUENCE-START BLOCK-MAPPING-START }
    flow_collection: { FLOW-SEQUENCE-START FLOW-MAPPING-START }
    block_sequence: { BLOCK-SEQUENCE-START }
    block_mapping: { BLOCK-MAPPING-START }
    block_node_or_indentless_sequence: { ALIAS ANCHOR TAG SCALAR BLOCK-SEQUENCE-START BLOCK-MAPPING-START FLOW-SEQUENCE-START FLOW-MAPPING-START BLOCK-ENTRY }
    indentless_sequence: { ENTRY }
    flow_collection: { FLOW-SEQUENCE-START FLOW-MAPPING-START }
    flow_sequence: { FLOW-SEQUENCE-START }
    flow_mapping: { FLOW-MAPPING-START }
    flow_sequence_entry: { ALIAS ANCHOR TAG SCALAR FLOW-SEQUENCE-START FLOW-MAPPING-START KEY }
    flow_mapping_entry: { ALIAS ANCHOR TAG SCALAR FLOW-SEQUENCE-START FLOW-MAPPING-START KEY }
    ```
    
    Since writing a recursive-descendant parser is a straightforward task, we do not give many
    comments here.
    """

    def __init__(self, reader: "StreamReader", options: "LoaderOptions"):
        ...


    def __init__(self, scanner: "Scanner"):
        ...


    def checkEvent(self, choice: "Event.ID") -> bool:
        """
        Check the type of the next event.
        """
        ...


    def peekEvent(self) -> "Event":
        """
        Peek the next event (keeping it in the stream)
        """
        ...


    def getEvent(self) -> "Event":
        """
        Get the next event and proceed further.
        """
        ...



"""
Python module generated from Java source file org.bukkit.plugin.InvalidPluginException

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class InvalidPluginException(Exception):
    """
    Thrown when attempting to load an invalid Plugin file
    """

    def __init__(self, cause: "Throwable"):
        """
        Constructs a new InvalidPluginException based on the given Exception

        Arguments
        - cause: Exception that triggered this Exception
        """
        ...


    def __init__(self):
        """
        Constructs a new InvalidPluginException
        """
        ...


    def __init__(self, message: str, cause: "Throwable"):
        """
        Constructs a new InvalidPluginException with the specified detail
        message and cause.

        Arguments
        - message: the detail message (which is saved for later retrieval
            by the getMessage() method).
        - cause: the cause (which is saved for later retrieval by the
            getCause() method). (A null value is permitted, and indicates that
            the cause is nonexistent or unknown.)
        """
        ...


    def __init__(self, message: str):
        """
        Constructs a new InvalidPluginException with the specified detail
        message

        Arguments
        - message: TThe detail message is saved for later retrieval by the
            getMessage() method.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableMapValues

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.io import Serializable
from java.util import Spliterator
from java.util.function import Consumer
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ImmutableMapValues(ImmutableCollection):
    """
    `values()` implementation for ImmutableMap.

    Author(s)
    - Kevin Bourrillion
    """

    def size(self) -> int:
        ...


    def iterator(self) -> "UnmodifiableIterator"["V"]:
        ...


    def spliterator(self) -> "Spliterator"["V"]:
        ...


    def contains(self, object: "Object") -> bool:
        ...


    def asList(self) -> "ImmutableList"["V"]:
        ...


    def forEach(self, action: "Consumer"["V"]) -> None:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.error.MissingEnvironmentVariableException

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import *
from typing import Any, Callable, Iterable, Tuple


class MissingEnvironmentVariableException(YAMLException):
    """
    Indicate missing mandatory environment variable in the template Used by EnvScalarConstructor
    """

    def __init__(self, message: str):
        ...



"""
Python module generated from Java source file org.bukkit.inventory.MerchantRecipe

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit import Material
from org.bukkit.entity import Villager
from org.bukkit.inventory import *
from org.bukkit.potion import PotionEffectType
from org.bukkit.util import NumberConversions
from typing import Any, Callable, Iterable, Tuple


class MerchantRecipe(Recipe):
    """
    Represents a merchant's trade.
    
    Trades can take one or two ingredients, and provide one result. The
    ingredients' ItemStack amounts are respected in the trade.
    
    A trade has a maximum number of uses. A Villager may periodically
    replenish its trades by resetting the .getUses uses of its merchant
    recipes to `0`, allowing them to be used again.
    
    A trade may or may not reward experience for being completed.
    
    During trades, the MerchantRecipe dynamically adjusts the amount of
    its first ingredient based on the following criteria:
    
    - .getDemand() Demand: This value is periodically updated by the
    villager that owns this merchant recipe based on how often the recipe has
    been used since it has been last restocked in relation to its
    .getMaxUses maximum uses. The amount by which the demand influences
    the amount of the first ingredient is scaled by the recipe's
    .getPriceMultiplier price multiplier, and can never be below zero.
    - .getSpecialPrice() Special price: This value is dynamically
    updated whenever a player starts and stops trading with a villager that owns
    this merchant recipe. It is based on the player's individual reputation with
    the villager, and the player's currently active status effects (see
    PotionEffectType.HERO_OF_THE_VILLAGE). The influence of the player's
    reputation on the special price is scaled by the recipe's
    .getPriceMultiplier price multiplier.
    
    The adjusted amount of the first ingredient is calculated by adding up the
    original amount of the first ingredient, the demand scaled by the recipe's
    .getPriceMultiplier price multiplier and truncated to the next lowest
    integer value greater than or equal to 0, and the special price, and then
    constraining the resulting value between `1` and the item stack's
    ItemStack.getMaxStackSize() maximum stack size.
    """

    def __init__(self, result: "ItemStack", maxUses: int):
        ...


    def __init__(self, result: "ItemStack", uses: int, maxUses: int, experienceReward: bool):
        ...


    def __init__(self, result: "ItemStack", uses: int, maxUses: int, experienceReward: bool, villagerExperience: int, priceMultiplier: float):
        ...


    def __init__(self, result: "ItemStack", uses: int, maxUses: int, experienceReward: bool, villagerExperience: int, priceMultiplier: float, demand: int, specialPrice: int):
        ...


    def getResult(self) -> "ItemStack":
        ...


    def addIngredient(self, item: "ItemStack") -> None:
        ...


    def removeIngredient(self, index: int) -> None:
        ...


    def setIngredients(self, ingredients: list["ItemStack"]) -> None:
        ...


    def getIngredients(self) -> list["ItemStack"]:
        ...


    def getAdjustedIngredient1(self) -> "ItemStack":
        """
        Gets the .adjust(ItemStack) adjusted first ingredient.

        Returns
        - the adjusted first ingredient, or `null` if this
        recipe has no ingredients

        See
        - .adjust(ItemStack)
        """
        ...


    def adjust(self, itemStack: "ItemStack") -> None:
        """
        Modifies the amount of the given ItemStack in the same way as
        MerchantRecipe dynamically adjusts the amount of the first ingredient
        during trading.
        
        This is calculated by adding up the original amount of the item, the
        demand scaled by the recipe's
        .getPriceMultiplier price multiplier and truncated to the next
        lowest integer value greater than or equal to 0, and the special price,
        and then constraining the resulting value between `1` and the
        ItemStack's ItemStack.getMaxStackSize()
        maximum stack size.

        Arguments
        - itemStack: the item to adjust
        """
        ...


    def getDemand(self) -> int:
        """
        Get the demand for this trade.

        Returns
        - the demand
        """
        ...


    def setDemand(self, demand: int) -> None:
        """
        Set the demand for this trade.

        Arguments
        - demand: the new demand
        """
        ...


    def getSpecialPrice(self) -> int:
        """
        Get the special price for this trade.

        Returns
        - special price value
        """
        ...


    def setSpecialPrice(self, specialPrice: int) -> None:
        """
        Set the special price for this trade.

        Arguments
        - specialPrice: special price value
        """
        ...


    def getUses(self) -> int:
        """
        Get the number of times this trade has been used.

        Returns
        - the number of uses
        """
        ...


    def setUses(self, uses: int) -> None:
        """
        Set the number of times this trade has been used.

        Arguments
        - uses: the number of uses
        """
        ...


    def getMaxUses(self) -> int:
        """
        Get the maximum number of uses this trade has.

        Returns
        - the maximum number of uses
        """
        ...


    def setMaxUses(self, maxUses: int) -> None:
        """
        Set the maximum number of uses this trade has.

        Arguments
        - maxUses: the maximum number of time this trade can be used
        """
        ...


    def hasExperienceReward(self) -> bool:
        """
        Whether to reward experience to the player for the trade.

        Returns
        - whether to reward experience to the player for completing this
        trade
        """
        ...


    def setExperienceReward(self, flag: bool) -> None:
        """
        Set whether to reward experience to the player for the trade.

        Arguments
        - flag: whether to reward experience to the player for completing
        this trade
        """
        ...


    def getVillagerExperience(self) -> int:
        """
        Gets the amount of experience the villager earns from this trade.

        Returns
        - villager experience
        """
        ...


    def setVillagerExperience(self, villagerExperience: int) -> None:
        """
        Sets the amount of experience the villager earns from this trade.

        Arguments
        - villagerExperience: new experience amount
        """
        ...


    def getPriceMultiplier(self) -> float:
        """
        Gets the price multiplier for the cost of this trade.

        Returns
        - price multiplier
        """
        ...


    def setPriceMultiplier(self, priceMultiplier: float) -> None:
        """
        Sets the price multiplier for the cost of this trade.

        Arguments
        - priceMultiplier: new price multiplier
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.constructor.Constructor

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.math import BigDecimal
from java.math import BigInteger
from java.util import Calendar
from java.util import Date
from java.util import UUID
from org.yaml.snakeyaml import LoaderOptions
from org.yaml.snakeyaml import TypeDescription
from org.yaml.snakeyaml.constructor import *
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.introspector import Property
from org.yaml.snakeyaml.nodes import MappingNode
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.nodes import NodeId
from org.yaml.snakeyaml.nodes import NodeTuple
from org.yaml.snakeyaml.nodes import ScalarNode
from org.yaml.snakeyaml.nodes import SequenceNode
from org.yaml.snakeyaml.nodes import Tag
from org.yaml.snakeyaml.util import EnumUtils
from typing import Any, Callable, Iterable, Tuple


class Constructor(SafeConstructor):
    """
    Construct a custom Java instance.
    """

    def __init__(self, loadingConfig: "LoaderOptions"):
        """
        Create with options

        Arguments
        - loadingConfig: - config
        """
        ...


    def __init__(self, theRoot: type["Object"], loadingConfig: "LoaderOptions"):
        """
        Create

        Arguments
        - theRoot: - the class to create (to be the root of the YAML document)
        - loadingConfig: - options
        """
        ...


    def __init__(self, theRoot: "TypeDescription", loadingConfig: "LoaderOptions"):
        """
        Create

        Arguments
        - theRoot: - the root class to create
        - loadingConfig: options
        """
        ...


    def __init__(self, theRoot: "TypeDescription", moreTDs: Iterable["TypeDescription"], loadingConfig: "LoaderOptions"):
        """
        Create with all possible arguments

        Arguments
        - theRoot: - the class (usually JavaBean) to be constructed
        - moreTDs: - collection of classes used by the root class
        - loadingConfig: - configuration
        """
        ...


    def __init__(self, theRoot: str, loadingConfig: "LoaderOptions"):
        """
        Create

        Arguments
        - theRoot: - the main class to crate
        - loadingConfig: - options

        Raises
        - ClassNotFoundException: if something goes wrong
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.FilteredMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Predicate
from com.google.common.collect import *
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class FilteredMultimap(Multimap):
    """
    An interface for all filtered multimap types.

    Author(s)
    - Louis Wasserman
    """

    def unfiltered(self) -> "Multimap"["K", "V"]:
        ...


    def entryPredicate(self) -> "Predicate"["Entry"["K", "V"]]:
        ...



"""
Python module generated from Java source file com.google.common.collect.EvictingQueue

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import Serializable
from java.util import ArrayDeque
from java.util import Queue
from typing import Any, Callable, Iterable, Tuple


class EvictingQueue(ForwardingQueue, Serializable):
    """
    A non-blocking queue which automatically evicts elements from the head of the queue when
    attempting to add new elements onto the queue and it is full. This queue orders elements FIFO
    (first-in-first-out). This data structure is logically equivalent to a circular buffer (i.e.,
    cyclic buffer or ring buffer).
    
    An evicting queue must be configured with a maximum size. Each time an element is added to a
    full queue, the queue automatically removes its head element. This is different from conventional
    bounded queues, which either block or reject new elements when full.
    
    This class is not thread-safe, and does not accept null elements.

    Author(s)
    - Kurt Alfred Kluever

    Since
    - 15.0
    """

    @staticmethod
    def create(maxSize: int) -> "EvictingQueue"["E"]:
        """
        Creates and returns a new evicting queue that will hold up to `maxSize` elements.
        
        When `maxSize` is zero, elements will be evicted immediately after being added to the
        queue.
        """
        ...


    def remainingCapacity(self) -> int:
        """
        Returns the number of additional elements that this queue can accept without evicting; zero if
        the queue is currently full.

        Since
        - 16.0
        """
        ...


    def offer(self, e: "E") -> bool:
        """
        Adds the given element to this queue. If the queue is currently full, the element at the head
        of the queue is evicted to make room.

        Returns
        - `True` always
        """
        ...


    def add(self, e: "E") -> bool:
        """
        Adds the given element to this queue. If the queue is currently full, the element at the head
        of the queue is evicted to make room.

        Returns
        - `True` always
        """
        ...


    def addAll(self, collection: Iterable["E"]) -> bool:
        ...


    def toArray(self) -> list["Object"]:
        ...



"""
Python module generated from Java source file com.google.gson.internal.bind.JsonTreeReader

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.gson import JsonArray
from com.google.gson import JsonElement
from com.google.gson import JsonNull
from com.google.gson import JsonObject
from com.google.gson import JsonPrimitive
from com.google.gson.internal.bind import *
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import MalformedJsonException
from java.io import IOException
from java.io import Reader
from java.util import Arrays
from java.util import Iterator
from typing import Any, Callable, Iterable, Tuple


class JsonTreeReader(JsonReader):
    """
    This reader walks the elements of a JsonElement as if it was coming from a character stream.

    Author(s)
    - Jesse Wilson
    """

    def __init__(self, element: "JsonElement"):
        ...


    def beginArray(self) -> None:
        ...


    def endArray(self) -> None:
        ...


    def beginObject(self) -> None:
        ...


    def endObject(self) -> None:
        ...


    def hasNext(self) -> bool:
        ...


    def peek(self) -> "JsonToken":
        ...


    def nextName(self) -> str:
        ...


    def nextString(self) -> str:
        ...


    def nextBoolean(self) -> bool:
        ...


    def nextNull(self) -> None:
        ...


    def nextDouble(self) -> float:
        ...


    def nextLong(self) -> int:
        ...


    def nextInt(self) -> int:
        ...


    def close(self) -> None:
        ...


    def skipValue(self) -> None:
        ...


    def toString(self) -> str:
        ...


    def promoteNameToValue(self) -> None:
        ...


    def getPath(self) -> str:
        ...


    def getPreviousPath(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.base.AbstractIterator

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from java.util import NoSuchElementException
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractIterator(Iterator):
    """
    Note this class is a copy of com.google.common.collect.AbstractIterator (for dependency
    reasons).
    """

    def hasNext(self) -> bool:
        ...


    def next(self) -> "T":
        ...


    def remove(self) -> None:
        ...
